from __future__ import annotations

from typing import Any, Optional

from .callbacks import EarlyStopping as EarlyStopping
from .callbacks import config_callbacks as config_callbacks
from .model_summary import summary as summary

def to_list(value: Any): ...
def to_numpy(var: Any): ...
def flatten_list(l: Any): ...
def restore_flatten_list(l: Any, splits: Any): ...
def extract_args(func: Any): ...
def wait_server_ready(endpoints: Any) -> None: ...
def init_communicator(
    program: Any, rank: Any, nranks: Any, wait_port: Any, current_endpoint: Any, endpoints: Any
) -> None: ...
def prepare_distributed_context(place: Optional[Any] = ...): ...

class StaticGraphAdapter:
    model: Any = ...
    def __init__(self, model: Any) -> None: ...
    @property
    def mode(self): ...
    @mode.setter
    def mode(self, value: Any) -> None: ...
    def train_batch(self, inputs: Any, labels: Optional[Any] = ..., update: bool = ...): ...
    def eval_batch(self, inputs: Any, labels: Optional[Any] = ...): ...
    def predict_batch(self, inputs: Any): ...
    def parameters(self, *args: Any, **kwargs: Any): ...
    def save(self, path: Any) -> None: ...
    def load(self, param_state_pairs: Any, optim_state: Any) -> None: ...
    def prepare(self) -> None: ...

class DynamicGraphAdapter:
    model: Any = ...
    ddp_model: Any = ...
    def __init__(self, model: Any) -> None: ...
    @property
    def mode(self): ...
    @mode.setter
    def mode(self, value: Any) -> None: ...
    def train_batch(self, inputs: Any, labels: Optional[Any] = ..., update: bool = ...): ...
    def eval_batch(self, inputs: Any, labels: Optional[Any] = ...): ...
    def predict_batch(self, inputs: Any): ...
    def parameters(self, *args: Any, **kwargs: Any): ...
    def save(self, path: Any) -> None: ...
    def load(self, param_state_pairs: Any, optim_state: Any, scaler_state: Optional[Any] = ...): ...
    def prepare(self) -> None: ...

class Model:
    mode: str = ...
    network: Any = ...
    stop_training: bool = ...
    def __init__(self, network: Any, inputs: Optional[Any] = ..., labels: Optional[Any] = ...) -> None: ...
    def train_batch(self, inputs: Any, labels: Optional[Any] = ..., update: bool = ...): ...
    def eval_batch(self, inputs: Any, labels: Optional[Any] = ...): ...
    def predict_batch(self, inputs: Any): ...
    def save(self, path: Any, training: bool = ...) -> None: ...
    def load(self, path: Any, skip_mismatch: bool = ..., reset_optimizer: bool = ...): ...
    def parameters(self, *args: Any, **kwargs: Any): ...
    def prepare(
        self,
        optimizer: Optional[Any] = ...,
        loss: Optional[Any] = ...,
        metrics: Optional[Any] = ...,
        amp_configs: Optional[Any] = ...,
    ) -> None: ...
    num_iters: Any = ...
    def fit(
        self,
        train_data: Optional[Any] = ...,
        eval_data: Optional[Any] = ...,
        batch_size: int = ...,
        epochs: int = ...,
        eval_freq: int = ...,
        log_freq: int = ...,
        save_dir: Optional[Any] = ...,
        save_freq: int = ...,
        verbose: int = ...,
        drop_last: bool = ...,
        shuffle: bool = ...,
        num_workers: int = ...,
        callbacks: Optional[Any] = ...,
        accumulate_grad_batches: int = ...,
        num_iters: Optional[Any] = ...,
    ) -> None: ...
    def evaluate(
        self,
        eval_data: Any,
        batch_size: int = ...,
        log_freq: int = ...,
        verbose: int = ...,
        num_workers: int = ...,
        callbacks: Optional[Any] = ...,
        num_iters: Optional[Any] = ...,
    ): ...
    def predict(
        self,
        test_data: Any,
        batch_size: int = ...,
        num_workers: int = ...,
        stack_outputs: bool = ...,
        verbose: int = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def summary(self, input_size: Optional[Any] = ..., dtype: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

class FunctionSpec:
    varargs_name: Any = ...
    def __init__(self, function: Any, input_spec: Optional[Any] = ...) -> None: ...
    def unified_args_and_kwargs(self, args: Any, kwargs: Any): ...
    def args_to_input_spec(self, args: Any, kwargs: Any): ...
    def to_static_inputs_with_spec(self, input_with_spec: Any, main_program: Any): ...
    @property
    def dygraph_function(self): ...
    @property
    def args_name(self): ...
    @property
    def input_spec(self): ...
    @property
    def flat_input_spec(self): ...
    @property
    def code(self): ...

def get_parameters(layer_instance: Any, include_sublayer: bool = ...): ...
def get_buffers(layer_instance: Any, include_sublayer: bool = ...): ...
def convert_to_input_spec(inputs: Any, input_spec: Any): ...
def replace_spec_empty_name(args_name: Any, input_with_spec: Any): ...



from __future__ import annotations

from typing import Any, Optional

class CostEstimator:
    def __init__(
        self, program: Any, cluster: Optional[Any] = ..., dist_context: Optional[Any] = ..., mode: str = ...
    ) -> None: ...
    @property
    def program(self): ...
    @property
    def dist_context(self): ...
    @property
    def cluster(self): ...
    @property
    def mode(self): ...
    @property
    def global_cost(self): ...
    @property
    def local_cost(self): ...
    def get_op_cost(self): ...
    def get_tensor_cost(self): ...
    def get_global_cost(self): ...
    def get_local_cost(self, rank: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.utils import gast

ORIGI_INFO: str
ORIGI_INFO_MAP: str

class Location:
    filepath: Any = ...
    lineno: Any = ...
    col_offset: Any = ...
    def __init__(self, filepath: Any, lineno: Any, col_offset: Optional[Any] = ...) -> None: ...
    @property
    def line_location(self): ...

class OriginInfo:
    location: Any = ...
    function_name: Any = ...
    source_code: Any = ...
    def __init__(self, location: Any, function_name: Any, source_code: Any) -> None: ...
    def formated_message(self): ...
    def as_frame(self): ...

class OriginInfoAttacher(gast.NodeTransformer):
    root: Any = ...
    func: Any = ...
    filepath: Any = ...
    source_code: Any = ...
    current_func: Any = ...
    def __init__(self, root: Any, func: Any) -> None: ...
    col_offset: Any = ...
    source_lines: Any = ...
    lineno_offset: Any = ...
    def transform(self) -> None: ...
    def visit(self, node: Any): ...

global_origin_info_map: Any

def create_and_update_origin_info_map(transformed_node: Any, static_func: Any, is_global: bool = ...): ...
def attach_origin_info(ast_node: Any, func: Any): ...
def ast_walk(transformed_node: Any, static_node: Any): ...
def update_op_callstack_with_origin_info(program: Any): ...



from __future__ import annotations

from typing import Any, Optional

from .. import Tensor
from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.data_feeder import convert_dtype as convert_dtype
from ..fluid.dygraph.inplace_utils import (
    inplace_apis_in_dygraph_only as inplace_apis_in_dygraph_only,
)
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper

def abs(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def acos(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def acosh(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def asin(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def asinh(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def atan(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def atanh(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def ceil(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def ceil_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def cos(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def cosh(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def erf(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def exp(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def exp_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def expm1(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def floor(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def floor_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def lgamma(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def log(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def multiplex(inputs: list[Tensor], index: Tensor, name: Optional[str] = ...) -> Tensor: ...
def reciprocal(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def reciprocal_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def round(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def round_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def rsqrt(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def rsqrt_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def scale(
    x: Tensor,
    scale: float | Tensor = ...,
    bias: float = ...,
    bias_after_scale: bool = ...,
    act: Optional[str] = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def sin(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def sinh(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def sqrt(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def sqrt_(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def square(x: Tensor, with_quant_attr: bool, name: Optional[str] = ...) -> Tensor: ...
def stanh(x: Tensor, scale_a: float = ..., scale_b: float = ..., name=Optional[str]) -> Tensor: ...
def tan(x: Tensor, scale_a: float = ..., scale_b: float = ..., name=Optional[str]) -> Tensor: ...

from ..fluid.layers.layer_function_generator import (
    generate_activation_fn as generate_activation_fn,
)
from ..fluid.layers.layer_function_generator import (
    generate_layer_fn as generate_layer_fn,
)
from ..framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..framework import core as core

def scale_(
    x: Any,
    scale: float = ...,
    bias: float = ...,
    bias_after_scale: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def pow(x: Any, y: Any, name: Optional[Any] = ...): ...

OP_NAMEMAPPING: Any

def add(x: Any, y: Any, name: Optional[Any] = ...): ...
def add_(x: Any, y: Any, name: Optional[Any] = ...): ...
def subtract(x: Any, y: Any, name: Optional[Any] = ...): ...
def subtract_(x: Any, y: Any, name: Optional[Any] = ...): ...
def divide(x: Any, y: Any, name: Optional[Any] = ...): ...
def floor_divide(x: Any, y: Any, name: Optional[Any] = ...): ...
def remainder(x: Any, y: Any, name: Optional[Any] = ...): ...

mod = remainder
floor_mod = remainder

def multiply(x: Any, y: Any, name: Optional[Any] = ...): ...
def maximum(x: Any, y: Any, name: Optional[Any] = ...): ...
def minimum(x: Any, y: Any, name: Optional[Any] = ...): ...
def fmax(x: Any, y: Any, name: Optional[Any] = ...): ...
def fmin(x: Any, y: Any, name: Optional[Any] = ...): ...

proto_dict: Any
op_proto: Any
additional_args_lines: Any

def sum(
    x: Any, axis: Optional[Any] = ..., dtype: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...
): ...
def nansum(
    x: Any, axis: Optional[Any] = ..., dtype: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...
): ...
def nanmean(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def add_n(inputs: Any, name: Optional[Any] = ...): ...
def trunc(input: Any, name: Optional[Any] = ...): ...
def mm(input: Any, mat2: Any, name: Optional[Any] = ...): ...
def addmm(input: Any, x: Any, y: Any, beta: float = ..., alpha: float = ..., name: Optional[Any] = ...): ...
def renorm(x: Any, p: Any, axis: Any, max_norm: Any): ...
def inner(x: Any, y: Any, name: Optional[Any] = ...): ...
def outer(x: Any, y: Any, name: Optional[Any] = ...): ...
def logsumexp(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def inverse(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def max(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def min(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def amax(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def amin(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def log1p(x: Any, name: Optional[Any] = ...): ...
def log2(x: Any, name: Optional[Any] = ...): ...
def log10(x: Any, name: Optional[Any] = ...): ...
def clip(x: Any, min: Optional[Any] = ..., max: Optional[Any] = ..., name: Optional[Any] = ...): ...
def clip_(x: Any, min: Optional[Any] = ..., max: Optional[Any] = ..., name: Optional[Any] = ...): ...
def trace(x: Any, offset: int = ..., axis1: int = ..., axis2: int = ..., name: Optional[Any] = ...): ...
def diagonal(x: Any, offset: int = ..., axis1: int = ..., axis2: int = ..., name: Optional[Any] = ...): ...
def kron(x: Any, y: Any, name: Optional[Any] = ...): ...
def cumsum(x: Any, axis: Optional[Any] = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def cumprod(x: Any, dim: Optional[Any] = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def isfinite(x: Any, name: Optional[Any] = ...): ...
def isinf(x: Any, name: Optional[Any] = ...): ...
def isnan(x: Any, name: Optional[Any] = ...): ...
def prod(
    x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...
): ...
def sign(x: Any, name: Optional[Any] = ...): ...
def tanh(x: Tensor, name: Optional[Any] = ...) -> Tensor: ...
def tanh_(x: Tensor, name: Optional[Any] = ...) -> Tensor: ...
def increment(x: Any, value: float = ..., name: Optional[Any] = ...): ...
def all(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def any(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def broadcast_shape(x_shape: Any, y_shape: Any): ...
def conj(x: Any, name: Optional[Any] = ...): ...
def digamma(x: Any, name: Optional[Any] = ...): ...
def neg(x: Any, name: Optional[Any] = ...): ...
def atan2(x: Any, y: Any, name: Optional[Any] = ...): ...
def logit(x: Any, eps: Optional[Any] = ..., name: Optional[Any] = ...): ...
def lerp(x: Any, y: Any, weight: Any, name: Optional[Any] = ...): ...
def lerp_(x: Any, y: Any, weight: Any, name: Optional[Any] = ...): ...
def erfinv(x: Any, name: Optional[Any] = ...): ...
def erfinv_(x: Any, name: Optional[Any] = ...): ...
def rad2deg(x: Any, name: Optional[Any] = ...): ...
def deg2rad(x: Any, name: Optional[Any] = ...): ...
def gcd(x: Any, y: Any, name: Optional[Any] = ...): ...
def lcm(x: Any, y: Any, name: Optional[Any] = ...): ...
def diff(
    x: Any,
    n: int = ...,
    axis: int = ...,
    prepend: Optional[Any] = ...,
    append: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def angle(x: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from collections import defaultdict as defaultdict
from typing import Any, Optional

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_attribute import append_op_input_suffix as append_op_input_suffix
from .dist_attribute import append_op_output_suffix as append_op_output_suffix
from .dist_attribute import get_op_dist_attr_field_keys as get_op_dist_attr_field_keys
from .dist_attribute import (
    get_tensor_dist_attr_field_keys as get_tensor_dist_attr_field_keys,
)

class DistributedOperator:
    def __init__(self, serial_op: Any, dist_attr: Optional[Any] = ...) -> None: ...
    @property
    def serial_op(self): ...
    @property
    def dist_attr(self): ...
    @dist_attr.setter
    def dist_attr(self, dist_attr: Any) -> None: ...
    def get_serial_input(self, name: Any): ...
    def get_serial_output(self, name: Any): ...
    def validate_dist_attr(self): ...
    def __deepcopy__(self, memo: Any): ...

class DistributedModule:
    def __init__(self, serial_module: Any, dist_attr: Optional[Any] = ...) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...



from __future__ import annotations

from typing import Any, Optional

class Optimizer:
    regularization: Any = ...
    helper: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        flatten_param_grads: bool = ...,
        align_size: int = ...,
        name: Optional[Any] = ...,
    ): ...
    def state_dict(self): ...
    def set_state_dict(self, state_dict: Any) -> None: ...
    set_dict: Any = ...
    def get_opti_var_name_list(self): ...
    def set_lr(self, value: Any) -> None: ...
    def current_step_lr(self): ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def append_regularization_ops(self, parameters_and_grads: Any, regularization: Optional[Any] = ...): ...
    def flatten_param_grads(self, params_grads: Any): ...
    def apply_gradients(self, params_grads: Any): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...
    def clear_gradients(self) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

class SGDOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        multi_precision: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class MomentumOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        momentum: Any,
        parameter_list: Optional[Any] = ...,
        use_nesterov: bool = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class DGCMomentumOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        momentum: Any,
        rampup_begin_step: Any,
        rampup_step: int = ...,
        sparsity: Any = ...,
        parameter_list: Optional[Any] = ...,
        use_nesterov: bool = ...,
        num_trainers: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def apply_gradients(self, params_grads: Any): ...

class LarsMomentumOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        momentum: Any,
        lars_coeff: float = ...,
        lars_weight_decay: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
        exclude_from_weight_decay: Optional[Any] = ...,
        epsilon: int = ...,
        multi_precision: bool = ...,
        rescale_grad: float = ...,
    ) -> None: ...

class AdagradOptimizer(Optimizer):
    type: str = ...
    initial_accumulator_value: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        epsilon: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
        initial_accumulator_value: float = ...,
    ) -> None: ...

class AdamOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        beta1: float = ...,
        beta2: float = ...,
        epsilon: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
        lazy_mode: bool = ...,
        use_global_beta_pow: bool = ...,
        flatten_param_grads: bool = ...,
        align_size: int = ...,
    ) -> None: ...

class AdamaxOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        beta1: float = ...,
        beta2: float = ...,
        epsilon: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class DpsgdOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        clip: float = ...,
        batch_size: float = ...,
        sigma: float = ...,
        parameter_list: Optional[Any] = ...,
    ) -> None: ...

class DecayedAdagradOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        decay: float = ...,
        epsilon: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class AdadeltaOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        epsilon: float = ...,
        rho: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class RMSPropOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        rho: float = ...,
        epsilon: float = ...,
        momentum: float = ...,
        centered: bool = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class FtrlOptimizer(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        l1: float = ...,
        l2: float = ...,
        lr_power: Any = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class LambOptimizer(AdamOptimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        lamb_weight_decay: float = ...,
        beta1: float = ...,
        beta2: float = ...,
        epsilon: float = ...,
        parameter_list: Optional[Any] = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        exclude_from_weight_decay_fn: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

SGD = SGDOptimizer
Momentum = MomentumOptimizer
Adagrad = AdagradOptimizer
Adam = AdamOptimizer
Adamax = AdamaxOptimizer
Dpsgd = DpsgdOptimizer
DecayedAdagrad = DecayedAdagradOptimizer
Adadelta = AdadeltaOptimizer
RMSProp = RMSPropOptimizer
Ftrl = FtrlOptimizer
LarsMomentum = LarsMomentumOptimizer
Lamb = LambOptimizer

class ModelAverage(Optimizer):
    average_window: Any = ...
    min_average_window: Any = ...
    max_average_window: Any = ...
    params_grads: Any = ...
    apply_program: Any = ...
    restore_program: Any = ...
    def __init__(
        self,
        average_window_rate: Any,
        min_average_window: int = ...,
        max_average_window: int = ...,
        regularization: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def apply(self, executor: Any, need_restore: bool = ...) -> None: ...
    def restore(self, executor: Any) -> None: ...

class ExponentialMovingAverage:
    apply_program: Any = ...
    restore_program: Any = ...
    def __init__(self, decay: float = ..., thres_steps: Optional[Any] = ..., name: Optional[Any] = ...) -> None: ...
    def update(self) -> None: ...
    def apply(self, executor: Any, need_restore: bool = ...) -> None: ...
    def restore(self, executor: Any) -> None: ...

class PipelineOptimizer:
    output_var_to_op: Any = ...
    input_var_to_op: Any = ...
    def __init__(self, optimizer: Any, num_microbatches: int = ..., start_cpu_core_id: int = ...) -> None: ...
    origin_main_block: Any = ...
    local_rank: Any = ...
    schedule_mode: Any = ...
    micro_batch_size: Any = ...
    use_sharding: Any = ...
    ring_id: Any = ...
    global_ring_id: Any = ...
    mp_degree: Any = ...
    mp_rank: Any = ...
    scale_gradient: Any = ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

class RecomputeOptimizer(Optimizer):
    enable_offload: bool = ...
    def __init__(self, optimizer: Any) -> None: ...
    def load(self, state_dict: Any) -> None: ...
    def apply_gradients(self, params_grads: Any): ...
    sorted_checkpoint_names: Any = ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

class LookaheadOptimizer:
    inner_optimizer: Any = ...
    alpha: Any = ...
    k: Any = ...
    type: str = ...
    def __init__(self, inner_optimizer: Any, alpha: float = ..., k: int = ...) -> None: ...
    def minimize(self, loss: Any, startup_program: Optional[Any] = ...): ...

class GradientMergeOptimizer:
    GRAD_MERGE_COND_NAME: str = ...
    inner_optimizer: Any = ...
    k_steps: Any = ...
    type: str = ...
    avg: Any = ...
    def __init__(self, inner_optimizer: Any, k_steps: int = ..., avg: bool = ...) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...
    def apply_gradients(self, params_grads: Any): ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any

from ... import Tensor, nn

class DepthwiseSeparable(nn.Layer):
    def __init__(
        self, in_channels: Any, out_channels1: Any, out_channels2: Any, num_groups: Any, stride: Any, scale: Any
    ) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class MobileNetV1(nn.Layer):
    def __init__(
        self,
        scale: float = ...,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    __call__ = forward

def mobilenet_v1(
    pretrained: bool = ...,
    scale: float = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> MobileNetV1: ...



from __future__ import annotations

from typing import Any, Optional

from .tunable_variable import Boolean as Boolean
from .tunable_variable import Choice as Choice
from .tunable_variable import Fixed as Fixed
from .tunable_variable import FloatRange as FloatRange
from .tunable_variable import IntRange as IntRange

class TunableSpace:
    def __init__(self) -> None: ...
    @property
    def variables(self): ...
    @property
    def values(self): ...
    def get_value(self, name: Any): ...
    def set_value(self, name: Any, value: Any) -> None: ...
    def __getitem__(self, name: Any): ...
    def __setitem__(self, name: Any, value: Any) -> None: ...
    def __contains__(self, name: Any): ...
    def fixed(self, name: Any, default: Any): ...
    def boolean(self, name: Any, default: bool = ...): ...
    def choice(self, name: Any, values: Any, default: Optional[Any] = ...): ...
    def int_range(self, name: Any, start: Any, stop: Any, step: int = ..., default: Optional[Any] = ...): ...
    def float_range(
        self, name: Any, start: Any, stop: Any, step: Optional[Any] = ..., default: Optional[Any] = ...
    ): ...
    def get_state(self): ...
    @classmethod
    def from_state(cls, state: Any): ...



from __future__ import annotations

from .amp_optimizer import AMPOptimizer as AMPOptimizer
from .asp_optimizer import ASPOptimizer as ASPOptimizer
from .dgc_optimizer import DGCOptimizer as DGCOptimizer
from .dygraph_optimizer import HeterParallelOptimizer as HeterParallelOptimizer
from .dygraph_optimizer import HybridParallelGradScaler as HybridParallelGradScaler
from .dygraph_optimizer import HybridParallelOptimizer as HybridParallelOptimizer
from .fp16_allreduce_optimizer import FP16AllReduceOptimizer as FP16AllReduceOptimizer
from .gradient_merge_optimizer import GradientMergeOptimizer as GradientMergeOptimizer
from .graph_execution_optimizer import (
    GraphExecutionOptimizer as GraphExecutionOptimizer,
)
from .lamb_optimizer import LambOptimizer as LambOptimizer
from .lars_optimizer import LarsOptimizer as LarsOptimizer
from .localsgd_optimizer import AdaptiveLocalSGDOptimizer as AdaptiveLocalSGDOptimizer
from .localsgd_optimizer import LocalSGDOptimizer as LocalSGDOptimizer
from .parameter_server_graph_optimizer import (
    ParameterServerGraphOptimizer as ParameterServerGraphOptimizer,
)
from .pipeline_optimizer import PipelineOptimizer as PipelineOptimizer
from .ps_optimizer import ParameterServerOptimizer as ParameterServerOptimizer
from .raw_program_optimizer import RawProgramOptimizer as RawProgramOptimizer
from .recompute_optimizer import RecomputeOptimizer as RecomputeOptimizer
from .sharding_optimizer import ShardingOptimizer as ShardingOptimizer
from .tensor_parallel_optimizer import (
    TensorParallelOptimizer as TensorParallelOptimizer,
)



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid import core as core
from paddle.metric import Metric as Metric

from .cluster import Cluster as Cluster
from .completion import Completer as Completer
from .dist_context import DistributedContext as DistributedContext
from .dist_context import (
    get_default_distributed_context as get_default_distributed_context,
)
from .dist_loader import NonIterableGeneratorLoader as NonIterableGeneratorLoader
from .dist_op import DistributedOperator as DistributedOperator
from .dist_saver import DistributedSaver as DistributedSaver
from .mapper import mapping as mapping
from .partitioner import Partitioner as Partitioner
from .planner import Planner as Planner
from .process_group import get_all_process_groups as get_all_process_groups
from .process_group import get_world_process_group as get_world_process_group
from .reshard import Resharder as Resharder
from .utils import make_data_unshard as make_data_unshard
from .utils import print_program_with_dist_attr as print_program_with_dist_attr
from .utils import set_grad_var_shape as set_grad_var_shape
from .utils import to_list as to_list

class Engine:
    model: Any = ...
    inputs_spec: Any = ...
    labels_spec: Any = ...
    cluster: Any = ...
    strategy: Any = ...
    def __init__(
        self,
        model: Optional[Any] = ...,
        inputs_spec: Optional[Any] = ...,
        labels_spec: Optional[Any] = ...,
        cluster: Optional[Any] = ...,
        strategy: Optional[Any] = ...,
    ) -> None: ...
    mode: Any = ...
    def prepare(
        self,
        optimizer: Optional[Any] = ...,
        loss: Optional[Any] = ...,
        metrics: Optional[Any] = ...,
        mode: str = ...,
        all_ranks: bool = ...,
    ) -> None: ...
    def fit(self, train_data: Any, batch_size: int = ..., epochs: int = ..., steps_per_epoch: Optional[Any] = ...): ...
    def predict(
        self, test_data: Any, batch_size: int = ..., use_program_cache: bool = ..., return_numpy: bool = ...
    ): ...
    def save(self, path: Any, training: bool = ..., mode: Optional[Any] = ...) -> None: ...
    def load(self, path: Any, strict: bool = ..., load_optimizer: bool = ..., mode: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .. import Layer as Layer

class LayerDict(Layer):
    def __init__(self, sublayers: Optional[Any] = ...) -> None: ...
    def __getitem__(self, key: Any): ...
    def __setitem__(self, key: Any, sublayer: Any): ...
    def __delitem__(self, key: Any) -> None: ...
    def __len__(self): ...
    def __iter__(self) -> Any: ...
    def __contains__(self, key: Any): ...
    def clear(self) -> None: ...
    def pop(self, key: Any): ...
    def keys(self): ...
    def items(self): ...
    def values(self): ...
    def update(self, sublayers: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .dataloader.dataloader_iter import default_collate_fn as default_collate_fn

class DataLoaderBase:
    def __init__(self) -> None: ...
    def __call__(self): ...
    def next(self): ...
    def __iter__(self) -> Any: ...
    def __next__(self) -> None: ...

class AuToTune:
    loader: Any = ...
    max_num_worker: Any = ...
    def __init__(self, loader: Any) -> None: ...
    def __call__(self): ...
    def need_autotune(self): ...
    def get_sub_dataset(self, dataset: Any, batch_size: Any): ...
    def get_autotune_loader(self): ...
    def evaluate_reader_cost(self, reader: Any): ...
    def is_best(self, reader: Any, best_workers: Any, best_time: Any, num_work_boundary: Any): ...

class DataLoader:
    return_list: Any = ...
    collate_fn: Any = ...
    use_buffer_reader: Any = ...
    prefetch_factor: Any = ...
    worker_init_fn: Any = ...
    dataset: Any = ...
    feed_list: Any = ...
    places: Any = ...
    num_workers: Any = ...
    use_shared_memory: Any = ...
    timeout: Any = ...
    dataset_kind: Any = ...
    batch_sampler: Any = ...
    batch_size: Any = ...
    drop_last: Any = ...
    auto_collate_batch: Any = ...
    pin_memory: bool = ...
    def __init__(
        self,
        dataset: Any,
        feed_list: Optional[Any] = ...,
        places: Optional[Any] = ...,
        return_list: bool = ...,
        batch_sampler: Optional[Any] = ...,
        batch_size: int = ...,
        shuffle: bool = ...,
        drop_last: bool = ...,
        collate_fn: Optional[Any] = ...,
        num_workers: int = ...,
        use_buffer_reader: bool = ...,
        prefetch_factor: int = ...,
        use_shared_memory: bool = ...,
        timeout: int = ...,
        worker_init_fn: Optional[Any] = ...,
        persistent_workers: bool = ...,
    ) -> None: ...
    def __len__(self): ...
    def __iter__(self) -> Any: ...
    def __call__(self): ...
    @staticmethod
    def from_generator(
        feed_list: Optional[Any] = ...,
        capacity: Optional[Any] = ...,
        use_double_buffer: bool = ...,
        iterable: bool = ...,
        return_list: bool = ...,
        use_multiprocess: bool = ...,
        drop_last: bool = ...,
    ): ...
    @staticmethod
    def from_dataset(dataset: Any, places: Any, drop_last: bool = ...): ...

class DygraphGeneratorLoader(DataLoaderBase):
    def __init__(
        self,
        feed_list: Optional[Any] = ...,
        capacity: Optional[Any] = ...,
        use_double_buffer: bool = ...,
        iterable: bool = ...,
        return_list: bool = ...,
        use_multiprocess: bool = ...,
    ) -> None: ...
    @property
    def queue(self): ...
    @property
    def iterable(self): ...
    def __iter__(self) -> Any: ...
    def __next__(self): ...
    def set_sample_generator(
        self, reader: Any, batch_size: Any, drop_last: bool = ..., places: Optional[Any] = ...
    ): ...
    def set_sample_list_generator(self, reader: Any, places: Optional[Any] = ...): ...
    def set_batch_generator(self, reader: Any, places: Optional[Any] = ...): ...

class GeneratorLoader(DataLoaderBase):
    def __init__(
        self,
        feed_list: Optional[Any] = ...,
        capacity: Optional[Any] = ...,
        use_double_buffer: bool = ...,
        iterable: bool = ...,
        return_list: bool = ...,
        drop_last: bool = ...,
    ) -> None: ...
    @property
    def queue(self): ...
    @property
    def iterable(self): ...
    def __iter__(self) -> Any: ...
    def __next__(self): ...
    def start(self) -> None: ...
    def reset(self) -> None: ...
    def set_sample_generator(
        self, reader: Any, batch_size: Any, drop_last: bool = ..., places: Optional[Any] = ...
    ): ...
    def set_sample_list_generator(self, reader: Any, places: Optional[Any] = ...): ...
    def set_batch_generator(self, reader: Any, places: Optional[Any] = ...): ...

class PyReader(DataLoaderBase):
    def __init__(
        self,
        feed_list: Optional[Any] = ...,
        capacity: Optional[Any] = ...,
        use_double_buffer: bool = ...,
        iterable: bool = ...,
        return_list: bool = ...,
    ) -> None: ...
    @property
    def queue(self): ...
    @property
    def iterable(self): ...
    def __iter__(self) -> Any: ...
    def __next__(self): ...
    def start(self) -> None: ...
    def reset(self) -> None: ...
    def decorate_sample_generator(
        self, sample_generator: Any, batch_size: Any, drop_last: bool = ..., places: Optional[Any] = ...
    ) -> None: ...
    def decorate_sample_list_generator(self, reader: Any, places: Optional[Any] = ...) -> None: ...
    def decorate_batch_generator(self, reader: Any, places: Optional[Any] = ...) -> None: ...

class DatasetLoader(DataLoaderBase):
    def __init__(self, dataset: Any, places: Any, drop_last: Any) -> None: ...
    def __iter__(self) -> Any: ...
    def __next__(self): ...



from __future__ import annotations

from .hapi.callbacks import Callback as Callback
from .hapi.callbacks import EarlyStopping as EarlyStopping
from .hapi.callbacks import LRScheduler as LRScheduler
from .hapi.callbacks import ModelCheckpoint as ModelCheckpoint
from .hapi.callbacks import ProgBarLogger as ProgBarLogger
from .hapi.callbacks import ReduceLROnPlateau as ReduceLROnPlateau
from .hapi.callbacks import VisualDL as VisualDL



from __future__ import annotations

from typing import Any, Optional

from paddle.distributed.fleet.meta_optimizers.common import (
    OP_ROLE_VAR_KEY as OP_ROLE_VAR_KEY,
)

def check_broadcast(block: Any) -> None: ...
def check_allreduce_sum(block: Any, shard: Any, sharding_ring_id: Any, dp_ring_id: int = ...) -> None: ...
def get_valid_op_role(block: Any, insert_idx: Any): ...
def insert_sync_calc_op(block: Any, insert_idx: Any, calc_dep_vars: Any) -> None: ...
def insert_sync_comm_op(block: Any, insert_idx: Any, ring_id: Any, comm_dep_vars: Any): ...
def insert_sync_comm_ops(block: Any, insert_idx: Any, ring_id: Any, comm_dep_vars: Any): ...
def insert_fill_constant_ops(block: Any, insert_idx: Any, fill_constant_vars: Any) -> None: ...
def insert_cast_ops(block: Any, insert_idx: Any, cast_ops: Any) -> None: ...
def insert_allreduce_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    allreduce_vars: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    user_defined_strategy: Optional[Any] = ...,
) -> None: ...

class FuseHelper:
    @staticmethod
    def sort_vars_by_dtype(block: Any, vars_name: Any): ...
    @staticmethod
    def get_fused_groups(block: Any, vars_name: Any, fuse_size: float = ...): ...
    @staticmethod
    def insert_coalesce_tensor(block: Any, index: Any, groups: Any, op_role: Any = ..., prefix: str = ...): ...

def insert_fused_allreduce_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    allreduce_vars: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    fuse_grad_size_in_MB: int = ...,
) -> None: ...
def insert_fused_reduce_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    reduce_vars: Any,
    shard: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    rank: Optional[Any] = ...,
    fuse_grad_size: int = ...,
): ...
def insert_reduce_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    reduce_vars: Any,
    shard: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    rank: Optional[Any] = ...,
    strategy: Optional[Any] = ...,
): ...
def insert_fused_broadcast_param_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    params: Any,
    shard: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    rank: Optional[Any] = ...,
    fuse_size: int = ...,
): ...
def insert_broadcast_param_ops(
    block: Any,
    insert_idx: Any,
    ring_id: Any,
    params: Any,
    shard: Any,
    op_role: Any = ...,
    use_calc_stream: bool = ...,
    rank: Optional[Any] = ...,
    strategy: Optional[Any] = ...,
): ...
def fuse_opt_broadcast_param_ops(
    block: Any, ring_id: Any, shard: Any, op_role: Any = ..., strategy: Optional[Any] = ...
) -> None: ...
def get_grad_device(grad_name: Any, shard: Any): ...
def get_first_check_finite_and_unscale_op_idx(block: Any, raise_error: bool = ...): ...
def get_first_optimize_op_idx(block: Any): ...
def insert_broadcast_ops(block: Any, insert_idx: Any, ring_id: Any, broadcast2root: Any) -> None: ...

DtypeToSize: Any

def get_var_size(param: Any): ...
def insert_scale_loss_grad_ops(block: Any, scale: float = ...) -> None: ...
def comm_analyse(main_program: Any): ...
def add_sync_comm(program: Any, sharding_ring_id: Any) -> None: ...
def save_persistables(exe: Any, dirname: Any, main_program: Any, filename: Optional[Any] = ...): ...
def append_naive_sync(block: Any, sync_var: Any, ring_id: Any) -> None: ...



from __future__ import annotations

from typing import Any

VOC_URL: str
VOC_MD5: str
SET_FILE: str
DATA_FILE: str
LABEL_FILE: str
CACHE_DIR: str

def reader_creator(filename: Any, sub_name: Any): ...
def train(): ...
def test(): ...
def val(): ...



from __future__ import annotations

from typing import Any, Optional

def check_finite_and_unscale(x: Any, scale: Any, name: Optional[Any] = ..., float_status: Optional[Any] = ...): ...
def update_loss_scaling(
    x: Any,
    found_inf: Any,
    prev_loss_scaling: Any,
    num_good_steps: Any,
    num_bad_steps: Any,
    incr_every_n_steps: Any,
    decr_every_n_nan_or_inf: Any,
    incr_ratio: Any,
    decr_ratio: Any,
    stop_update: bool = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from .cost_model import estimate_cost as estimate_cost
from .interface import shard_op as shard_op
from .interface import shard_tensor as shard_tensor
from .process_mesh import ProcessMesh as ProcessMesh
from .reshard import Resharder as Resharder



from __future__ import annotations

from typing import Any, Optional

from ...fluid.data_feeder import check_type as check_type
from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.layers import LayerHelper as LayerHelper
from ...fluid.layers import utils as utils
from ...tensor.manipulation import squeeze as squeeze
from ...tensor.manipulation import unsqueeze as unsqueeze

def avg_pool1d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    exclusive: bool = ...,
    ceil_mode: bool = ...,
    name: Optional[Any] = ...,
): ...
def avg_pool2d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    ceil_mode: bool = ...,
    exclusive: bool = ...,
    divisor_override: Optional[Any] = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def avg_pool3d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    ceil_mode: bool = ...,
    exclusive: bool = ...,
    divisor_override: Optional[Any] = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def max_pool1d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    return_mask: bool = ...,
    ceil_mode: bool = ...,
    name: Optional[Any] = ...,
): ...
def max_unpool1d(
    x: Any,
    indices: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    data_format: str = ...,
    output_size: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def max_unpool2d(
    x: Any,
    indices: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    data_format: str = ...,
    output_size: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def max_unpool3d(
    x: Any,
    indices: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    data_format: str = ...,
    output_size: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def max_pool2d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    return_mask: bool = ...,
    ceil_mode: bool = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def max_pool3d(
    x: Any,
    kernel_size: Any,
    stride: Optional[Any] = ...,
    padding: int = ...,
    return_mask: bool = ...,
    ceil_mode: bool = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def adaptive_avg_pool1d(x: Any, output_size: Any, name: Optional[Any] = ...): ...
def adaptive_avg_pool2d(x: Any, output_size: Any, data_format: str = ..., name: Optional[Any] = ...): ...
def adaptive_avg_pool3d(x: Any, output_size: Any, data_format: str = ..., name: Optional[Any] = ...): ...
def adaptive_max_pool1d(x: Any, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...): ...
def adaptive_max_pool2d(x: Any, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...): ...
def adaptive_max_pool3d(x: Any, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.incubate.fleet.parameter_server.ir.ps_dispatcher import (
    PSDispatcher as PSDispatcher,
)
from paddle.fluid.transpiler.details.program_utils import delete_ops as delete_ops

OP_NAME_SCOPE: str
CLIP_OP_NAME_SCOPE: str
STEP_COUNTER: str
LEARNING_RATE_DECAY_COUNTER: str
OP_ROLE_VAR_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_VALUE: Any
op_role_attr_name: Any
LR_SCHED_OP_ROLE_ATTR_VALUE: Any
OPT_OP_ROLE_ATTR_VALUE: Any
SPARSE_OP_LIST: Any
SPARSE_OP_TYPE_DICT: Any

def is_sparse_op(op: Any): ...
def is_distributed_sparse_op(op: Any): ...
def get_sparse_tablename(op: Any): ...
def get_sparse_tablenames(program: Any, is_distributed: Any): ...

class MergedVariable:
    merged_var: Any = ...
    ordered_vars: Any = ...
    offsets: Any = ...
    def __init__(self, merged: Any, ordered: Any, offsets: Any) -> None: ...

def Singleton(cls): ...

class CompileTimeStrategy:
    min_block_size: int = ...
    origin_main_program: Any = ...
    origin_startup_program: Any = ...
    origin_ps_main_program: Any = ...
    origin_ps_startup_program: Any = ...
    strategy: Any = ...
    role_maker: Any = ...
    use_ps_gpu: bool = ...
    is_heter_ps_mode: Any = ...
    origin_sparse_pairs: Any = ...
    origin_dense_pairs: Any = ...
    merged_variables_pairs: Any = ...
    merged_dense_pairs: Any = ...
    merged_sparse_pairs: Any = ...
    merged_variable_map: Any = ...
    param_name_to_grad_name: Any = ...
    grad_name_to_param_name: Any = ...
    param_grad_ep_mapping: Any = ...
    grad_param_mapping: Any = ...
    tensor_table_dict: Any = ...
    origin_merged_variables_pairs: Any = ...
    origin_merged_dense_pairs: Any = ...
    origin_merged_sparse_pairs: Any = ...
    def __init__(self, main_program: Any, startup_program: Any, strategy: Any, role_maker: Any) -> None: ...
    def get_distributed_mode(self): ...
    def is_sync_mode(self): ...
    def is_geo_mode(self): ...
    def is_async_mode(self): ...
    def get_role_id(self): ...
    def get_trainers(self): ...
    def get_ps_endpoint(self): ...
    def get_ps_endpoints(self): ...
    def get_heter_worker_endpoints(self): ...
    def get_next_stage_trainers(self): ...
    def get_heter_worker_endpoint(self): ...
    def get_trainer_endpoints(self): ...
    def get_trainer_endpoint(self): ...
    def get_previous_stage_trainers(self): ...
    def get_origin_programs(self): ...
    def get_origin_main_program(self): ...
    def get_origin_startup_program(self): ...
    def set_origin_ps_main_program(self, program: Any) -> None: ...
    def set_origin_ps_startup_program(self, program: Any) -> None: ...
    def get_origin_ps_main_program(self): ...
    def get_origin_ps_startup_program(self): ...
    def add_tensor_table(
        self,
        feed_var_name: Any,
        fetch_var_name: str = ...,
        startup_program: Optional[Any] = ...,
        main_program: Optional[Any] = ...,
        tensor_table_class: str = ...,
    ) -> None: ...
    def get_tensor_table_dict(self): ...
    def get_sparse_varname_on_ps(self, is_distributed: Any, endpoint: Optional[Any] = ...): ...
    def get_optimize_varname_on_ps(self, param_name: Any): ...
    def build_ctx(
        self, vars: Any, mapping: Any, is_grad: Any, is_sparse: Any, is_send: Any, is_distributed: bool = ...
    ): ...
    def get_trainer_send_context(self): ...
    def get_communicator_send_context(self): ...
    def get_communicator_recv_context(self, recv_type: int = ..., use_origin_program: bool = ...): ...
    def get_the_one_trainer_send_context(self, split_dense_table: Any): ...
    def get_dense_send_context(
        self, send_ctx: Any, idx: Any, merged_dense_pairs: Any, trainer_id: Any, split_dense_table: bool = ...
    ): ...
    def get_the_one_send_context(
        self, split_dense_table: bool = ..., use_origin_program: bool = ..., ep_list: Optional[Any] = ...
    ): ...
    def get_the_one_recv_context(
        self, is_dense: bool = ..., split_dense_table: bool = ..., use_origin_program: bool = ...
    ): ...
    def get_server_runtime_config(self): ...
    def get_var_distributed(self, varname: Any, is_param: Any): ...
    def get_param_grads(self): ...
    def remove_var_pair_by_grad(self, var_name: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def convert_while_loop(cond: Any, body: Any, loop_vars: Any): ...
def convert_logical_and(x_func: Any, y_func: Any): ...
def convert_logical_or(x_func: Any, y_func: Any): ...
def convert_logical_not(x: Any): ...
def convert_ifelse(pred: Any, true_fn: Any, false_fn: Any, true_args: Any, false_args: Any, return_vars: Any): ...
def convert_len(var: Any): ...
def convert_zip(*args: Any): ...
def convert_var_shape(x: Any, idx: Optional[Any] = ..., in_control_flow: bool = ...): ...
def convert_var_shape_simple(x: Any): ...
def eval_if_exist_else_none(name: Any, global_symbol_table: Any): ...
def choose_shape_attr_or_api(attr_shape: Any, api_shape: Any, idx: Optional[Any] = ...): ...
def convert_shape_compare(left: Any, *args: Any): ...
def cast_bool_if_necessary(var: Any): ...
def convert_var_dtype(var: Any, dtype: Any): ...
def convert_assert(cond: Any, message: str = ...): ...
def convert_print(*args: Any) -> None: ...
def convert_pop(target: Any, *args: Any): ...



from __future__ import annotations

from typing import Any

URL: str
MD5: str
feature_names: Any
UCI_TRAIN_DATA: Any
UCI_TEST_DATA: Any
FLUID_URL_MODEL: str
FLUID_MD5_MODEL: str

def feature_range(maximums: Any, minimums: Any) -> None: ...
def load_data(filename: Any, feature_num: int = ..., ratio: float = ...) -> None: ...
def train(): ...
def test(): ...
def fluid_model(): ...
def predict_reader(): ...
def fetch() -> None: ...



from __future__ import annotations

from .spectral_norm_hook import spectral_norm as spectral_norm
from .transform_parameters import parameters_to_vector as parameters_to_vector
from .transform_parameters import vector_to_parameters as vector_to_parameters
from .weight_norm_hook import remove_weight_norm as remove_weight_norm
from .weight_norm_hook import weight_norm as weight_norm



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class CastTransformer(gast.NodeTransformer):
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Call(self, node: Any): ...



from __future__ import annotations

from . import functional as functional
from .distributed_fused_lamb import DistributedFusedLamb as DistributedFusedLamb
from .lookahead import LookAhead as LookAhead
from .modelaverage import ModelAverage as ModelAverage



from __future__ import annotations

from typing import Any

from ..utils.fs import FS as FS
from ..utils.fs import HDFSClient as HDFSClient
from ..utils.fs import LocalFS as LocalFS

class UtilFactory: ...

class UtilBase:
    role_maker: Any = ...
    dist_strategy: Any = ...
    def __init__(self) -> None: ...
    def all_reduce(self, input: Any, mode: str = ..., comm_world: str = ...): ...
    def barrier(self, comm_world: str = ...) -> None: ...
    def all_gather(self, input: Any, comm_world: str = ...): ...
    def get_file_shard(self, files: Any): ...
    def print_on_rank(self, message: Any, rank_id: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

import numpy as np
from paddle.common_ops_import import core as core
from typing_extensions import Literal

from .. import Tensor
from ..fluid import layers as layers
from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import cast as cast
from ..fluid.layers import transpose as transpose
from ..static import Variable as Variable

K_DEFAULT_DIM: int

def matmul(x: Any, y: Any, transpose_x: bool = ..., transpose_y: bool = ..., name: Optional[Any] = ...): ...
def norm(
    x: Tensor,
    # TODO: Only support "fro", inf, -inf, 0, 1, 2
    p: Literal["fro"] | float = ...,
    axis: Optional[int | list[int] | tuple[int, ...]] = ...,
    keepdim: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def dist(x: Any, y: Any, p: int = ..., name: Optional[Any] = ...): ...
def cond(
    x: Tensor,
    # TODO: Only support "fro", "nuc", 1, -1, 2, -2, inf, -inf
    #       but now Literal does not support inf
    p: Optional[Literal["fro", "nuc"] | float] = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def dot(x: Any, y: Any, name: Optional[Any] = ...): ...
def cov(
    x: Tensor,
    rowvar: bool = ...,
    ddof: bool = ...,
    fweights: Optional[Tensor] = ...,
    aweights: Optional[Tensor] = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def t(input: Any, name: Optional[Any] = ...): ...
def cross(x: Any, y: Any, axis: int = ..., name: Optional[Any] = ...): ...
def cholesky(x: Tensor, upper: bool = ..., name: Optional[str] = ...) -> Tensor: ...
def matrix_rank(
    x: Tensor,
    tol: Optional[float | Tensor] = ...,
    hermitian: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def bmm(x: Any, y: Any, name: Optional[Any] = ...): ...
def histogram(input: Any, bins: int = ..., min: int = ..., max: int = ..., name: Optional[Any] = ...): ...
def bincount(x: Any, weights: Optional[Any] = ..., minlength: int = ..., name: Optional[Any] = ...): ...
def mv(x: Any, vec: Any, name: Optional[Any] = ...): ...
def det(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def slogdet(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def svd(
    x: Tensor,
    full_matrices: bool = ...,
    name: Optional[str] = ...,
) -> tuple[Tensor, Tensor, Tensor]: ...
def matrix_power(x: Tensor, n: int, name: Optional[str] = ...) -> Tensor: ...
def qr(
    x: Tensor,
    mode: Literal["reduced", "complete", "r"] = ...,
    name: Optional[str] = ...,
) -> tuple[Tensor, Tensor]: ...
def lu(
    x: Tensor,
    pivot: bool = ...,
    get_infos: bool = ...,
    name: Optional[str] = ...,
) -> tuple[Tensor, Tensor, Tensor]: ...
def lu_unpack(
    x: Tensor,
    y: Tensor,
    unpack_ludata: bool = ...,
    unpack_pivots: bool = ...,
    name: Optional[str] = ...,
) -> tuple[Tensor, Tensor, Tensor]: ...
def eig(x: Tensor, name: Optional[str] = ...) -> tuple[Tensor, Tensor]: ...
def eigvals(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def multi_dot(x: list[Tensor], name: Optional[str] = ...) -> Tensor: ...
def eigh(x: Tensor, UPLO: str = ..., name: Optional[str] = ...) -> tuple[Tensor, Tensor]: ...
def pinv(
    x: Tensor,
    rcond: float = ...,
    hermitian: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def solve(x: Tensor, y: Tensor, name: Optional[str] = ...) -> Tensor: ...
def triangular_solve(
    x: Tensor,
    y: Tensor,
    upper: bool = ...,
    transpose: bool = ...,
    unitriangular: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def cholesky_solve(x: Tensor, y: Tensor, upper: bool = ..., name: Optional[str] = ...) -> Tensor: ...
def eigvalsh(x: Tensor, UPLO: str = ..., name: Optional[str] = ...) -> Tensor: ...
def lstsq(
    x: Tensor,
    y: Tensor,
    rcond: Optional[float] = ...,
    driver: Optional[Literal["gels", "gelsy", "gelsd", "gelss"]] = ...,
    name: Optional[str] = ...,
) -> tuple[Tensor, Tensor, Tensor, Tensor]: ...



from __future__ import annotations

from collections import namedtuple
from typing import Any, Optional

from ... import tensor as tensor
from ...fluid import layers as layers
from ...framework import ParamAttr as ParamAttr
from .. import Layer as Layer
from .. import LayerList as LayerList
from .common import Dropout as Dropout
from .common import Linear as Linear
from .norm import LayerNorm as LayerNorm

class MultiHeadAttention(Layer):
    Cache = namedtuple("Cache", ["k", "v"])

    StaticCache = namedtuple("StaticCache", ["k", "v"])
    embed_dim: Any = ...
    kdim: Any = ...
    vdim: Any = ...
    num_heads: Any = ...
    dropout: Any = ...
    need_weights: Any = ...
    head_dim: Any = ...
    q_proj: Any = ...
    k_proj: Any = ...
    v_proj: Any = ...
    out_proj: Any = ...
    def __init__(
        self,
        embed_dim: Any,
        num_heads: Any,
        dropout: float = ...,
        kdim: Optional[Any] = ...,
        vdim: Optional[Any] = ...,
        need_weights: bool = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
    ) -> None: ...
    def compute_kv(self, key: Any, value: Any): ...
    def gen_cache(self, key: Any, value: Optional[Any] = ..., type: Any = ...): ...
    def forward(
        self,
        query: Any,
        key: Optional[Any] = ...,
        value: Optional[Any] = ...,
        attn_mask: Optional[Any] = ...,
        cache: Optional[Any] = ...,
    ): ...

class TransformerEncoderLayer(Layer):
    normalize_before: Any = ...
    self_attn: Any = ...
    linear1: Any = ...
    dropout: Any = ...
    linear2: Any = ...
    norm1: Any = ...
    norm2: Any = ...
    dropout1: Any = ...
    dropout2: Any = ...
    activation: Any = ...
    def __init__(
        self,
        d_model: Any,
        nhead: Any,
        dim_feedforward: Any,
        dropout: float = ...,
        activation: str = ...,
        attn_dropout: Optional[Any] = ...,
        act_dropout: Optional[Any] = ...,
        normalize_before: bool = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, src: Any, src_mask: Optional[Any] = ..., cache: Optional[Any] = ...): ...
    def gen_cache(self, src: Any): ...

class TransformerEncoder(Layer):
    layers: Any = ...
    num_layers: Any = ...
    norm: Any = ...
    def __init__(self, encoder_layer: Any, num_layers: Any, norm: Optional[Any] = ...) -> None: ...
    def forward(self, src: Any, src_mask: Optional[Any] = ..., cache: Optional[Any] = ...): ...
    def gen_cache(self, src: Any): ...

class TransformerDecoderLayer(Layer):
    normalize_before: Any = ...
    self_attn: Any = ...
    cross_attn: Any = ...
    linear1: Any = ...
    dropout: Any = ...
    linear2: Any = ...
    norm1: Any = ...
    norm2: Any = ...
    norm3: Any = ...
    dropout1: Any = ...
    dropout2: Any = ...
    dropout3: Any = ...
    activation: Any = ...
    def __init__(
        self,
        d_model: Any,
        nhead: Any,
        dim_feedforward: Any,
        dropout: float = ...,
        activation: str = ...,
        attn_dropout: Optional[Any] = ...,
        act_dropout: Optional[Any] = ...,
        normalize_before: bool = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
    ) -> None: ...
    def forward(
        self,
        tgt: Any,
        memory: Any,
        tgt_mask: Optional[Any] = ...,
        memory_mask: Optional[Any] = ...,
        cache: Optional[Any] = ...,
    ): ...
    def gen_cache(self, memory: Any): ...

class TransformerDecoder(Layer):
    layers: Any = ...
    num_layers: Any = ...
    norm: Any = ...
    def __init__(self, decoder_layer: Any, num_layers: Any, norm: Optional[Any] = ...) -> None: ...
    def forward(
        self,
        tgt: Any,
        memory: Any,
        tgt_mask: Optional[Any] = ...,
        memory_mask: Optional[Any] = ...,
        cache: Optional[Any] = ...,
    ): ...
    def gen_cache(self, memory: Any, do_zip: bool = ...): ...

class Transformer(Layer):
    encoder: Any = ...
    decoder: Any = ...
    d_model: Any = ...
    nhead: Any = ...
    def __init__(
        self,
        d_model: int = ...,
        nhead: int = ...,
        num_encoder_layers: int = ...,
        num_decoder_layers: int = ...,
        dim_feedforward: int = ...,
        dropout: float = ...,
        activation: str = ...,
        attn_dropout: Optional[Any] = ...,
        act_dropout: Optional[Any] = ...,
        normalize_before: bool = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        custom_encoder: Optional[Any] = ...,
        custom_decoder: Optional[Any] = ...,
    ) -> None: ...
    def forward(
        self,
        src: Any,
        tgt: Any,
        src_mask: Optional[Any] = ...,
        tgt_mask: Optional[Any] = ...,
        memory_mask: Optional[Any] = ...,
    ): ...
    def generate_square_subsequent_mask(self, length: Any): ...



from __future__ import annotations

import unittest
from typing import Any

def init_data(batch_size: int = ..., img_shape: Any = ..., label_range: int = ...): ...

class TestMovingAverageAbsMaxScaleOp(unittest.TestCase):
    def check_backward(self, use_cuda: Any) -> None: ...
    def test_check_op_times(self) -> None: ...



from __future__ import annotations

from enum import Enum
from typing import Any

class OptimizerState(Enum):
    INIT = ...
    UNSCALED = ...
    STEPPED = ...

class AmpScaler:
    def __init__(
        self,
        enable: bool = ...,
        init_loss_scaling: Any = ...,
        incr_ratio: float = ...,
        decr_ratio: float = ...,
        incr_every_n_steps: int = ...,
        decr_every_n_nan_or_inf: int = ...,
        use_dynamic_loss_scaling: bool = ...,
    ) -> None: ...
    def scale(self, var: Any): ...
    def minimize(self, optimizer: Any, *args: Any, **kwargs: Any): ...
    def is_enable(self): ...
    def is_use_dynamic_loss_scaling(self): ...
    def get_init_loss_scaling(self): ...
    def set_init_loss_scaling(self, new_init_loss_scaling: Any) -> None: ...
    def get_incr_ratio(self): ...
    def set_incr_ratio(self, new_incr_ratio: Any) -> None: ...
    def get_decr_ratio(self): ...
    def set_decr_ratio(self, new_decr_ratio: Any) -> None: ...
    def get_incr_every_n_steps(self): ...
    def set_incr_every_n_steps(self, new_incr_every_n_steps: Any) -> None: ...
    def get_decr_every_n_nan_or_inf(self): ...
    def set_decr_every_n_nan_or_inf(self, new_decr_every_n_nan_or_inf: Any) -> None: ...
    def state_dict(self): ...
    def load_state_dict(self, state_dict: Any) -> None: ...



from __future__ import annotations

from paddle.cuda_env import *

from . import hub as hub
from . import linalg as linalg
from . import metric as metric
from . import nn as nn
from . import optimizer as optimizer
from . import regularizer as regularizer
from . import signal as signal
from . import sysconfig as sysconfig
from . import vision as vision
from ._typing import Tensor as Tensor
from .autograd import grad as grad
from .autograd import is_grad_enabled as is_grad_enabled
from .autograd import no_grad as no_grad
from .autograd import set_grad_enabled as set_grad_enabled
from .batch import batch as batch
from .framework import CPUPlace as CPUPlace
from .framework import CUDAPinnedPlace as CUDAPinnedPlace
from .framework import CUDAPlace as CUDAPlace
from .framework import DataParallel as DataParallel
from .framework import NPUPlace as NPUPlace
from .framework import ParamAttr as ParamAttr
from .framework import create_parameter as create_parameter
from .framework import disable_signal_handler as disable_signal_handler
from .framework import disable_static as disable_static
from .framework import enable_static as enable_static
from .framework import get_default_dtype as get_default_dtype
from .framework import get_flags as get_flags
from .framework import in_dynamic_mode as in_dynamic_mode
from .framework import load as load
from .framework import save as save
from .framework import set_default_dtype as set_default_dtype
from .framework import set_flags as set_flags
from .framework.dtype import bfloat16 as bfloat16
from .framework.dtype import bool as bool
from .framework.dtype import complex64 as complex64
from .framework.dtype import complex128 as complex128
from .framework.dtype import dtype as dtype
from .framework.dtype import float16 as float16
from .framework.dtype import float32 as float32
from .framework.dtype import float64 as float64
from .framework.dtype import int8 as int8
from .framework.dtype import int16 as int16
from .framework.dtype import int32 as int32
from .framework.dtype import int64 as int64
from .framework.dtype import uint8 as uint8
from .framework.random import get_cuda_rng_state as get_cuda_rng_state
from .framework.random import seed as seed
from .framework.random import set_cuda_rng_state as set_cuda_rng_state
from .hapi import Model as Model
from .hapi import flops as flops
from .hapi import summary as summary
from .tensor.attribute import imag as imag
from .tensor.attribute import is_complex as is_complex
from .tensor.attribute import is_floating_point as is_floating_point
from .tensor.attribute import is_integer as is_integer
from .tensor.attribute import rank as rank
from .tensor.attribute import real as real
from .tensor.attribute import shape as shape
from .tensor.creation import arange as arange
from .tensor.creation import assign as assign
from .tensor.creation import clone as clone
from .tensor.creation import complex as complex
from .tensor.creation import diag as diag
from .tensor.creation import diagflat as diagflat
from .tensor.creation import empty as empty
from .tensor.creation import empty_like as empty_like
from .tensor.creation import eye as eye
from .tensor.creation import full as full
from .tensor.creation import full_like as full_like
from .tensor.creation import linspace as linspace
from .tensor.creation import meshgrid as meshgrid
from .tensor.creation import ones as ones
from .tensor.creation import ones_like as ones_like
from .tensor.creation import to_tensor as to_tensor
from .tensor.creation import tril as tril
from .tensor.creation import triu as triu
from .tensor.creation import zeros as zeros
from .tensor.creation import zeros_like as zeros_like
from .tensor.einsum import einsum as einsum
from .tensor.linalg import bincount as bincount
from .tensor.linalg import bmm as bmm
from .tensor.linalg import cross as cross
from .tensor.linalg import dist as dist
from .tensor.linalg import dot as dot
from .tensor.linalg import histogram as histogram
from .tensor.linalg import matmul as matmul
from .tensor.linalg import mv as mv
from .tensor.linalg import t as t
from .tensor.linalg import transpose as transpose
from .tensor.logic import allclose as allclose
from .tensor.logic import bitwise_and as bitwise_and
from .tensor.logic import bitwise_not as bitwise_not
from .tensor.logic import bitwise_or as bitwise_or
from .tensor.logic import bitwise_xor as bitwise_xor
from .tensor.logic import equal as equal
from .tensor.logic import equal_all as equal_all
from .tensor.logic import greater_equal as greater_equal
from .tensor.logic import greater_than as greater_than
from .tensor.logic import is_empty as is_empty
from .tensor.logic import is_tensor as is_tensor
from .tensor.logic import isclose as isclose
from .tensor.logic import less_equal as less_equal
from .tensor.logic import less_than as less_than
from .tensor.logic import logical_and as logical_and
from .tensor.logic import logical_not as logical_not
from .tensor.logic import logical_or as logical_or
from .tensor.logic import logical_xor as logical_xor
from .tensor.logic import not_equal as not_equal
from .tensor.manipulation import as_complex as as_complex
from .tensor.manipulation import as_real as as_real
from .tensor.manipulation import broadcast_tensors as broadcast_tensors
from .tensor.manipulation import broadcast_to as broadcast_to
from .tensor.manipulation import cast as cast
from .tensor.manipulation import chunk as chunk
from .tensor.manipulation import concat as concat
from .tensor.manipulation import crop as crop
from .tensor.manipulation import expand as expand
from .tensor.manipulation import expand_as as expand_as
from .tensor.manipulation import flatten as flatten
from .tensor.manipulation import flip as flip
from .tensor.manipulation import flip as reverse
from .tensor.manipulation import gather as gather
from .tensor.manipulation import gather_nd as gather_nd
from .tensor.manipulation import moveaxis as moveaxis
from .tensor.manipulation import put_along_axis as put_along_axis
from .tensor.manipulation import repeat_interleave as repeat_interleave
from .tensor.manipulation import reshape as reshape
from .tensor.manipulation import reshape_ as reshape_
from .tensor.manipulation import roll as roll
from .tensor.manipulation import rot90 as rot90
from .tensor.manipulation import scatter as scatter
from .tensor.manipulation import scatter_ as scatter_
from .tensor.manipulation import scatter_nd as scatter_nd
from .tensor.manipulation import scatter_nd_add as scatter_nd_add
from .tensor.manipulation import shard_index as shard_index
from .tensor.manipulation import slice as slice
from .tensor.manipulation import split as split
from .tensor.manipulation import squeeze as squeeze
from .tensor.manipulation import squeeze_ as squeeze_
from .tensor.manipulation import stack as stack
from .tensor.manipulation import strided_slice as strided_slice
from .tensor.manipulation import take_along_axis as take_along_axis
from .tensor.manipulation import tensordot as tensordot
from .tensor.manipulation import tile as tile
from .tensor.manipulation import tolist as tolist
from .tensor.manipulation import unbind as unbind
from .tensor.manipulation import unique as unique
from .tensor.manipulation import unique_consecutive as unique_consecutive
from .tensor.manipulation import unsqueeze as unsqueeze
from .tensor.manipulation import unsqueeze_ as unsqueeze_
from .tensor.manipulation import unstack as unstack
from .tensor.math import abs as abs
from .tensor.math import acos as acos
from .tensor.math import acosh as acosh
from .tensor.math import add as add
from .tensor.math import add_n as add_n
from .tensor.math import addmm as addmm
from .tensor.math import all as all
from .tensor.math import amax as amax
from .tensor.math import amin as amin
from .tensor.math import angle as angle
from .tensor.math import any as any
from .tensor.math import asin as asin
from .tensor.math import asinh as asinh
from .tensor.math import atan as atan
from .tensor.math import atan2 as atan2
from .tensor.math import atanh as atanh
from .tensor.math import broadcast_shape as broadcast_shape
from .tensor.math import ceil as ceil
from .tensor.math import clip as clip
from .tensor.math import conj as conj
from .tensor.math import cos as cos
from .tensor.math import cosh as cosh
from .tensor.math import cumprod as cumprod
from .tensor.math import cumsum as cumsum
from .tensor.math import deg2rad as deg2rad
from .tensor.math import diagonal as diagonal
from .tensor.math import diff as diff
from .tensor.math import digamma as digamma
from .tensor.math import divide as divide
from .tensor.math import erf as erf
from .tensor.math import erfinv as erfinv
from .tensor.math import exp as exp
from .tensor.math import expm1 as expm1
from .tensor.math import floor as floor
from .tensor.math import floor_divide as floor_divide
from .tensor.math import floor_mod as floor_mod
from .tensor.math import fmax as fmax
from .tensor.math import fmin as fmin
from .tensor.math import gcd as gcd
from .tensor.math import increment as increment
from .tensor.math import inner as inner
from .tensor.math import isfinite as isfinite
from .tensor.math import isinf as isinf
from .tensor.math import isnan as isnan
from .tensor.math import kron as kron
from .tensor.math import lcm as lcm
from .tensor.math import lerp as lerp
from .tensor.math import lgamma as lgamma
from .tensor.math import log as log
from .tensor.math import log1p as log1p
from .tensor.math import log2 as log2
from .tensor.math import log10 as log10
from .tensor.math import logit as logit
from .tensor.math import logsumexp as logsumexp
from .tensor.math import max as max
from .tensor.math import maximum as maximum
from .tensor.math import min as min
from .tensor.math import minimum as minimum
from .tensor.math import mm as mm
from .tensor.math import mod as mod
from .tensor.math import multiplex as multiplex
from .tensor.math import multiply as multiply
from .tensor.math import nanmean as nanmean
from .tensor.math import nansum as nansum
from .tensor.math import neg as neg
from .tensor.math import outer as outer
from .tensor.math import pow as pow
from .tensor.math import prod as prod
from .tensor.math import rad2deg as rad2deg
from .tensor.math import reciprocal as reciprocal
from .tensor.math import remainder as remainder
from .tensor.math import renorm as renorm
from .tensor.math import round as round
from .tensor.math import rsqrt as rsqrt
from .tensor.math import scale as scale
from .tensor.math import sign as sign
from .tensor.math import sin as sin
from .tensor.math import sinh as sinh
from .tensor.math import sqrt as sqrt
from .tensor.math import square as square
from .tensor.math import stanh as stanh
from .tensor.math import subtract as subtract
from .tensor.math import sum as sum
from .tensor.math import tan as tan
from .tensor.math import tanh as tanh
from .tensor.math import tanh_ as tanh_
from .tensor.math import trace as trace
from .tensor.math import trunc as trunc
from .tensor.random import bernoulli as bernoulli
from .tensor.random import check_shape as check_shape
from .tensor.random import multinomial as multinomial
from .tensor.random import normal as normal
from .tensor.random import poisson as poisson
from .tensor.random import rand as rand
from .tensor.random import randint as randint
from .tensor.random import randint_like as randint_like
from .tensor.random import randn as randn
from .tensor.random import randperm as randperm
from .tensor.random import standard_normal as standard_normal
from .tensor.random import uniform as uniform
from .tensor.search import argmax as argmax
from .tensor.search import argmin as argmin
from .tensor.search import argsort as argsort
from .tensor.search import index_sample as index_sample
from .tensor.search import index_select as index_select
from .tensor.search import kthvalue as kthvalue
from .tensor.search import masked_select as masked_select
from .tensor.search import mode as mode
from .tensor.search import nonzero as nonzero
from .tensor.search import searchsorted as searchsorted
from .tensor.search import sort as sort
from .tensor.search import topk as topk
from .tensor.search import where as where
from .tensor.stat import mean as mean
from .tensor.stat import median as median
from .tensor.stat import numel as numel
from .tensor.stat import quantile as quantile
from .tensor.stat import std as std
from .tensor.stat import var as var
from .tensor.to_string import set_printoptions as set_printoptions



from __future__ import annotations

from typing import Any

from .. import core as core

DataType = Any
PlaceType = Any
PrecisionType: Any
Config = Any
Tensor = Any
Predictor = Any

def tensor_copy_from_cpu(self, data: Any) -> None: ...
def tensor_share_external_data(self, data: Any) -> None: ...



from __future__ import annotations

from typing import Any

from ... import Tensor, nn
from ..ops import ConvNormActivation as ConvNormActivation

model_urls: Any

class InvertedResidual(nn.Layer):
    stride: Any = ...
    use_res_connect: Any = ...
    conv: Any = ...
    def __init__(self, inp: Any, oup: Any, stride: Any, expand_ratio: Any, norm_layer: Any = ...) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class MobileNetV2(nn.Layer):
    def __init__(
        self,
        scale: float = ...,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    __call__ = forward

def mobilenet_v2(
    pretrained: bool = ...,
    scale: float = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> MobileNetV2: ...



from __future__ import annotations

from .datasets import WMT14 as WMT14
from .datasets import WMT16 as WMT16
from .datasets import Conll05st as Conll05st
from .datasets import Imdb as Imdb
from .datasets import Imikolov as Imikolov
from .datasets import Movielens as Movielens
from .datasets import UCIHousing as UCIHousing
from .viterbi_decode import ViterbiDecoder as ViterbiDecoder
from .viterbi_decode import viterbi_decode as viterbi_decode



from __future__ import annotations

from typing import Any, Optional

from ..base.private_helper_function import wait_server_ready as wait_server_ready
from .meta_optimizer_base import MetaOptimizerBase as MetaOptimizerBase

class GraphExecutionOptimizer(MetaOptimizerBase):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    meta_optimizers_black_list: Any = ...
    def __init__(self, optimizer: Any) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any

URL: str
MD5: str

def tokenize(pattern: Any) -> None: ...
def build_dict(pattern: Any, cutoff: Any): ...
def reader_creator(pos_pattern: Any, neg_pattern: Any, word_idx: Any): ...
def train(word_idx: Any): ...
def test(word_idx: Any): ...
def word_dict(): ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any

ETCD_PROTOCAL: str

class Master:
    MAIN: str = ...
    STANDBY: str = ...
    PATICIPANT: str = ...
    ctx: Any = ...
    server: Any = ...
    initialized: bool = ...
    endpoint: Any = ...
    def __init__(self, ctx: Any) -> None: ...
    def stop(self) -> None: ...
    def set_status(self, status: Any) -> None: ...
    def get_status(self) -> None: ...
    def restart_peer(self) -> None: ...
    def sync_peers(self, prefix: Any, key: Any, value: Any, size: Any, rank: Any = ...) -> tuple[list, int]: ...
    @classmethod
    def factory(cls, ctx: Any): ...

class HTTPMaster(Master):
    role: Any = ...
    endpoint: Any = ...
    server: Any = ...
    client: Any = ...
    initialized: bool = ...
    def lazy_init(self) -> None: ...
    def stop(self) -> None: ...
    def sync_peers(self, prefix: Any, key: Any, value: Any, size: Any, rank: Any = ...) -> tuple[list, int]: ...

class ETCDMaster(Master):
    endpoint: Any = ...
    client: Any = ...
    def __init__(self, ctx: Any) -> None: ...
    def sync_peers(self, prefix: Any, key: Any, value: Any, size: Any, rank: Any = ...) -> tuple[list, int]: ...
    job_prefix: Any = ...
    heartbeat_prefix: Any = ...
    beat_thread: Any = ...
    def register_heartbeat(self, job_id: Any, pod_id: Any, ttl: int = ...) -> None: ...
    def fetch_peer_alive(self): ...
    def wait_peer_ready(self, replicas_min: Any, replicas_max: Any, timeout: Any): ...
    def restart_peer(self) -> None: ...
    def set_status(self, status: Any) -> None: ...
    def get_status(self): ...
    def stop(self) -> None: ...



from __future__ import annotations

from sys import version_info as version_info
from typing import Any

from ..data_feeder import check_dtype as check_dtype
from ..data_feeder import check_type as check_type
from ..data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..data_feeder import convert_dtype as convert_dtype
from ..framework import Block as Block
from ..framework import Variable as Variable
from ..layer_helper import LayerHelper as LayerHelper

def convert_to_list(value: Any, n: Any, name: Any, dtype: Any = ...): ...
def is_sequence(seq: Any): ...
def flatten(nest: Any): ...
def pack_sequence_as(structure: Any, flat_sequence: Any): ...
def map_structure(func: Any, *structure: Any): ...
def hold_mutable_vars(structure: Any): ...
def copy_mutable_vars(structure: Any): ...
def assert_same_structure(nest1: Any, nest2: Any, check_types: bool = ...) -> None: ...
def get_shape_tensor_inputs(inputs: Any, attrs: Any, shape: Any, op_type: Any): ...
def convert_shape_to_list(shape: Any): ...
def check_shape(shape: Any) -> None: ...
def try_set_static_shape_tensor(tensor: Any, shape: Any) -> None: ...
def try_get_constant_shape_from_tensor(shape_tensor: Any): ...
def get_inputs_outputs_in_block(block: Any): ...



from __future__ import annotations

from .distribute_transpiler import DistributeTranspiler as DistributeTranspiler
from .distribute_transpiler import (
    DistributeTranspilerConfig as DistributeTranspilerConfig,
)
from .memory_optimization_transpiler import memory_optimize as memory_optimize
from .memory_optimization_transpiler import release_memory as release_memory
from .ps_dispatcher import HashName as HashName
from .ps_dispatcher import RoundRobin as RoundRobin



from __future__ import annotations

from typing import Any

def cubic_interpolation_(x1: Any, f1: Any, g1: Any, x2: Any, f2: Any, g2: Any): ...
def strong_wolfe(
    f: Any,
    xk: Any,
    pk: Any,
    max_iters: int = ...,
    tolerance_change: float = ...,
    initial_step_length: float = ...,
    c1: float = ...,
    c2: float = ...,
    alpha_max: int = ...,
    dtype: str = ...,
): ...



from __future__ import annotations

from paddle.distributed.fleet.dataset import InMemoryDataset as InMemoryDataset
from paddle.distributed.fleet.dataset import QueueDataset as QueueDataset
from paddle.fluid.dygraph.parallel import ParallelEnv as ParallelEnv

from .collective import ReduceOp as ReduceOp
from .collective import all_gather as all_gather
from .collective import all_reduce as all_reduce
from .collective import alltoall as alltoall
from .collective import barrier as barrier
from .collective import broadcast as broadcast
from .collective import get_group as get_group
from .collective import new_group as new_group
from .collective import recv as recv
from .collective import reduce as reduce
from .collective import scatter as scatter
from .collective import send as send
from .collective import split as split
from .collective import wait as wait
from .entry_attr import CountFilterEntry as CountFilterEntry
from .entry_attr import ProbabilityEntry as ProbabilityEntry
from .entry_attr import ShowClickEntry as ShowClickEntry
from .launch.main import launch as launch
from .parallel import get_rank as get_rank
from .parallel import get_world_size as get_world_size
from .parallel import init_parallel_env as init_parallel_env
from .parallel_with_gloo import gloo_barrier as gloo_barrier
from .parallel_with_gloo import gloo_init_parallel_env as gloo_init_parallel_env
from .parallel_with_gloo import gloo_release as gloo_release
from .sharding import *
from .spawn import spawn as spawn



from __future__ import annotations

from typing import Any

from paddle.fluid.framework import Variable as Variable
from paddle.fluid.framework import core as core
from paddle.fluid.framework import set_flags as set_flags

non_auto_func_called: bool

def __non_auto_func_called__(func: Any): ...

is_strict_auto: Any

def get_msg_dict(msg: Any): ...
def assign_configs_value(msg: Any, config: Any) -> None: ...
def check_configs_key(msg: Any, config: Any, field_name: Any) -> None: ...

class DistributedJobInfo:
    job_info: Any = ...
    def __init__(self) -> None: ...

ReduceStrategyFluid: Any
ReduceStrategyFleet = int

class DistributedStrategy:
    strategy: Any = ...
    def __init__(self) -> None: ...
    def __setattr__(self, key: Any, value: Any) -> None: ...
    def save_to_prototxt(self, output: Any) -> None: ...
    def load_from_prototxt(self, pb_file: Any) -> None: ...
    @property
    def execution_strategy(self): ...
    @execution_strategy.setter
    def execution_strategy(self, strategy: Any) -> None: ...
    @property
    def build_strategy(self): ...
    @build_strategy.setter
    def build_strategy(self, strategy: Any) -> None: ...
    @property
    def gradient_scale_configs(self): ...
    @gradient_scale_configs.setter
    def gradient_scale_configs(self, config: Any) -> None: ...
    @property
    def a_sync(self): ...
    @a_sync.setter
    def a_sync(self, flag: Any) -> None: ...
    @property
    def a_sync_configs(self): ...
    @a_sync_configs.setter
    def a_sync_configs(self, configs: Any) -> None: ...
    @property
    def trainer_desc_configs(self): ...
    @property
    def adam_d2sum(self): ...
    @adam_d2sum.setter
    def adam_d2sum(self, flag: Any) -> None: ...
    @trainer_desc_configs.setter
    def trainer_desc_configs(self, configs: Any) -> None: ...
    @property
    def fs_client_param(self): ...
    @fs_client_param.setter
    def fs_client_param(self, configs: Any) -> None: ...
    @property
    def sparse_table_configs(self): ...
    @sparse_table_configs.setter
    def sparse_table_configs(self, configs: Any) -> None: ...
    @sparse_table_configs.setter
    def fleet_desc_configs(self, configs: Any) -> None: ...
    @property
    def amp(self): ...
    @amp.setter
    def amp(self, flag: Any) -> None: ...
    @property
    def amp_configs(self): ...
    @amp_configs.setter
    def amp_configs(self, configs: Any) -> None: ...
    @property
    def asp(self): ...
    @asp.setter
    def asp(self, flag: Any) -> None: ...
    @property
    def recompute(self): ...
    @property
    def sync_nccl_allreduce(self): ...
    @sync_nccl_allreduce.setter
    def sync_nccl_allreduce(self, flag: Any) -> None: ...
    @property
    def use_hierarchical_allreduce(self): ...
    @use_hierarchical_allreduce.setter
    def use_hierarchical_allreduce(self, flag: Any) -> None: ...
    @property
    def hierarchical_allreduce_inter_nranks(self): ...
    @hierarchical_allreduce_inter_nranks.setter
    def hierarchical_allreduce_inter_nranks(self, value: Any) -> None: ...
    @property
    def sync_batch_norm(self): ...
    @sync_batch_norm.setter
    def sync_batch_norm(self, flag: Any) -> None: ...
    @property
    def fuse_all_reduce_ops(self): ...
    @fuse_all_reduce_ops.setter
    def fuse_all_reduce_ops(self, flag: Any) -> None: ...
    @property
    def fuse_grad_size_in_MB(self): ...
    @fuse_grad_size_in_MB.setter
    def fuse_grad_size_in_MB(self, value: Any) -> None: ...
    @property
    def last_comm_group_size_MB(self): ...
    @last_comm_group_size_MB.setter
    def last_comm_group_size_MB(self, value: Any) -> None: ...
    @property
    def find_unused_parameters(self): ...
    @find_unused_parameters.setter
    def find_unused_parameters(self, flag: Any) -> None: ...
    @property
    def nccl_comm_num(self): ...
    @nccl_comm_num.setter
    def nccl_comm_num(self, value: Any) -> None: ...
    @recompute.setter
    def recompute(self, flag: Any) -> None: ...
    @property
    def recompute_configs(self): ...
    @recompute_configs.setter
    def recompute_configs(self, configs: Any) -> None: ...
    @property
    def sharding(self): ...
    @sharding.setter
    def sharding(self, flag: Any) -> None: ...
    @property
    def sharding_configs(self): ...
    @sharding_configs.setter
    def sharding_configs(self, configs: Any) -> None: ...
    @property
    def without_graph_optimization(self): ...
    @without_graph_optimization.setter
    def without_graph_optimization(self, flag: Any) -> None: ...
    @property
    def fuse_grad_merge(self): ...
    @fuse_grad_merge.setter
    def fuse_grad_merge(self, fuse_grad_merge: Any) -> None: ...
    @property
    def fuse_grad_size_in_num(self): ...
    @fuse_grad_size_in_num.setter
    def fuse_grad_size_in_num(self, num: Any) -> None: ...
    @property
    def pipeline(self): ...
    @pipeline.setter
    def pipeline(self, flag: Any) -> None: ...
    @property
    def pipeline_configs(self): ...
    @pipeline_configs.setter
    def pipeline_configs(self, configs: Any) -> None: ...
    @property
    def tensor_parallel(self): ...
    @tensor_parallel.setter
    def tensor_parallel(self, flag: Any) -> None: ...
    @property
    def tensor_parallel_configs(self): ...
    @tensor_parallel_configs.setter
    def tensor_parallel_configs(self, configs: Any) -> None: ...
    @property
    def hybrid_configs(self): ...
    @hybrid_configs.setter
    def hybrid_configs(self, configs: Any) -> None: ...
    @property
    def localsgd(self): ...
    @localsgd.setter
    def localsgd(self, flag: Any) -> None: ...
    @property
    def localsgd_configs(self): ...
    @localsgd_configs.setter
    def localsgd_configs(self, configs: Any) -> None: ...
    @property
    def adaptive_localsgd(self): ...
    @adaptive_localsgd.setter
    def adaptive_localsgd(self, flag: Any) -> None: ...
    @property
    def adaptive_localsgd_configs(self): ...
    @adaptive_localsgd_configs.setter
    def adaptive_localsgd_configs(self, configs: Any) -> None: ...
    @property
    def dgc(self): ...
    @dgc.setter
    def dgc(self, flag: Any) -> None: ...
    @property
    def dgc_configs(self): ...
    @dgc_configs.setter
    def dgc_configs(self, configs: Any) -> None: ...
    @property
    def fp16_allreduce(self): ...
    @fp16_allreduce.setter
    def fp16_allreduce(self, flag: Any) -> None: ...
    @property
    def gradient_merge(self): ...
    @gradient_merge.setter
    def gradient_merge(self, flag: Any) -> None: ...
    @property
    def gradient_merge_configs(self): ...
    @gradient_merge_configs.setter
    def gradient_merge_configs(self, configs: Any) -> None: ...
    @property
    def lars(self): ...
    @lars.setter
    def lars(self, flag: Any) -> None: ...
    @property
    def lars_configs(self): ...
    @lars_configs.setter
    def lars_configs(self, configs: Any) -> None: ...
    @property
    def lamb(self): ...
    @lamb.setter
    def lamb(self, flag: Any) -> None: ...
    @property
    def lamb_configs(self): ...
    @lamb_configs.setter
    def lamb_configs(self, configs: Any) -> None: ...
    @property
    def elastic(self): ...
    @elastic.setter
    def elastic(self, flag: Any) -> None: ...
    @property
    def auto(self): ...
    @auto.setter
    def auto(self, flag: Any) -> None: ...
    @property
    def semi_auto(self): ...
    @semi_auto.setter
    def semi_auto(self, flag: Any) -> None: ...
    @property
    def auto_search(self): ...
    @auto_search.setter
    def auto_search(self, flag: Any) -> None: ...
    @property
    def heter_ccl_mode(self): ...
    @heter_ccl_mode.setter
    def heter_ccl_mode(self, flag: Any) -> None: ...
    @property
    def cudnn_exhaustive_search(self): ...
    @cudnn_exhaustive_search.setter
    def cudnn_exhaustive_search(self, flag: Any) -> None: ...
    @property
    def conv_workspace_size_limit(self): ...
    @conv_workspace_size_limit.setter
    def conv_workspace_size_limit(self, value: Any) -> None: ...
    @property
    def cudnn_batchnorm_spatial_persistent(self): ...
    @cudnn_batchnorm_spatial_persistent.setter
    def cudnn_batchnorm_spatial_persistent(self, flag: Any) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.fluid.dygraph.layers import Layer

class MetaParallelBase(Layer):
    def __init__(self, layers: Any, hcg: Any, strategy: Any) -> None: ...
    def forward(self, *inputs: Any, **kwargs: Any): ...



from __future__ import annotations

from typing import Any, Optional

class AutoMixedPrecisionListsBF16:
    bf16_list: Any = ...
    fp32_list: Any = ...
    gray_list: Any = ...
    bf16_initializer_list: Any = ...
    unsupported_list: Any = ...
    fp32_varnames: Any = ...
    def __init__(
        self,
        custom_bf16_list: Optional[Any] = ...,
        custom_fp32_list: Optional[Any] = ...,
        custom_fp32_varnames: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any

from ... import Tensor, nn
from ...framework import ParamAttr

def xavier(channels: int, filter_size: int) -> ParamAttr: ...

class ConvLayer(nn.Layer):
    def __init__(
        self, num_channels: Any, num_filters: Any, filter_size: Any, stride: int = ..., groups: int = ...
    ) -> None: ...
    def forward(self, inputs: Any) -> Tensor: ...

class Inception(nn.Layer):
    def __init__(
        self,
        input_channels: Any,
        output_channels: Any,
        filter1: Any,
        filter3R: Any,
        filter3: Any,
        filter5R: Any,
        filter5: Any,
        proj: Any,
    ) -> None: ...
    def forward(self, inputs: Any) -> Tensor: ...

class GoogLeNet(nn.Layer):
    def __init__(
        self,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, inputs: Tensor) -> tuple[Tensor, Tensor, Tensor]: ...
    __call__ = forward

def googlenet(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> GoogLeNet: ...



from __future__ import annotations

import paddle.fluid as fluid

class L1Decay(fluid.regularizer.L1Decay):
    def __init__(self, coeff: float = ...) -> None: ...

class L2Decay(fluid.regularizer.L2Decay):
    def __init__(self, coeff: float = ...) -> None: ...



from __future__ import annotations

class Status:
    UNINIT: str = ...
    READY: str = ...
    RUNNING: str = ...
    FAILED: str = ...
    TERMINATING: str = ...
    RESTARTING: str = ...
    UNKNOWN: str = ...
    COMPLETED: str = ...



from __future__ import annotations

from .adadelta import Adadelta as Adadelta
from .adagrad import Adagrad as Adagrad
from .adam import Adam as Adam
from .adamax import Adamax as Adamax
from .adamw import AdamW as AdamW
from .lamb import Lamb as Lamb
from .momentum import Momentum as Momentum
from .optimizer import Optimizer as Optimizer
from .rmsprop import RMSProp as RMSProp
from .sgd import SGD as SGD



from __future__ import annotations

from .metrics import Accuracy as Accuracy
from .metrics import Auc as Auc
from .metrics import Metric as Metric
from .metrics import Precision as Precision
from .metrics import Recall as Recall
from .metrics import accuracy as accuracy



from __future__ import annotations

import http.server as SimpleHTTPServer
from http.server import HTTPServer
from typing import Any

def get_logger(name: Any, level: Any, fmt: Any): ...

class KVHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
    def do_GET(self) -> None: ...
    def do_PUT(self) -> None: ...
    def do_DELETE(self) -> None: ...
    def log_message(self, format: Any, *args: Any) -> None: ...
    def send_status_code(self, code: Any) -> None: ...

class KVHTTPServer(HTTPServer):
    delete_kv_lock: Any = ...
    delete_kv: Any = ...
    kv_lock: Any = ...
    kv: Any = ...
    def __init__(self, port: Any, handler: Any) -> None: ...
    def get_deleted_size(self, key: Any): ...

class KVServer:
    http_server: Any = ...
    listen_thread: Any = ...
    size: Any = ...
    def __init__(self, port: Any, size: Any = ...) -> None: ...
    def start(self): ...
    def stop(self) -> None: ...
    def should_stop(self): ...



from __future__ import annotations

from collections import namedtuple
from typing import Any, Optional

from paddle.utils import gast

PADDLE_MODULE_PREFIX: str
DYGRAPH_MODULE_PREFIX: str
DYGRAPH_TO_STATIC_MODULE_PREFIX: str

class BaseNodeVisitor(gast.NodeVisitor):
    ancestor_nodes: Any = ...
    def __init__(self) -> None: ...
    def visit(self, node: Any): ...

dygraph_class_to_static_api: Any
FOR_ITER_INDEX_PREFIX: str
FOR_ITER_TUPLE_PREFIX: str
FOR_ITER_TUPLE_INDEX_PREFIX: str
FOR_ITER_VAR_LEN_PREFIX: str
FOR_ITER_VAR_NAME_PREFIX: str
FOR_ITER_ZIP_TO_LIST_PREFIX: str

FullArgSpec = namedtuple(
    "FullArgSpec", ["args", "varargs", "varkw", "defaults", "kwonlyargs", "kwonlydefaults", "annotations"]
)

def getfullargspec(target: Any): ...
def parse_arg_and_kwargs(function: Any): ...
def parse_varargs_name(function: Any): ...
def type_name(v: Any): ...
def make_hashable(x: Any, error_msg: Optional[Any] = ...): ...
def is_api_in_module(node: Any, module_prefix: Any): ...
def is_dygraph_api(node: Any): ...
def is_paddle_api(node: Any): ...
def is_paddle_func(func: Any): ...
def is_numpy_api(node: Any): ...
def is_control_flow_to_transform(
    node: Any, static_analysis_visitor: Optional[Any] = ..., var_name_to_type: Optional[Any] = ...
): ...
def to_static_api(dygraph_class: Any): ...
def to_static_ast(node: Any, class_node: Any): ...
def update_args_of_func(node: Any, dygraph_node: Any, method_name: Any) -> None: ...
def create_api_shape_node(tensor_shape_node: Any): ...
def get_constant_variable_node(name: Any, value: Any, shape: Any = ..., dtype: str = ...): ...
def get_attribute_full_name(node: Any): ...
def generate_name_node(name_ids: Any, ctx: Any = ..., gen_tuple_if_single: bool = ...): ...
def create_funcDef_node(nodes: Any, name: Any, input_args: Any, return_name_ids: Any): ...
def index_in_list(array_list: Any, item: Any): ...
def create_assign_node(name: Any, node: Any): ...

class RenameTransformer(gast.NodeTransformer):
    root: Any = ...
    old_name: str = ...
    new_name: str = ...
    def __init__(self, node: Any) -> None: ...
    def rename(self, old_name: Any, new_name: Any) -> None: ...
    def visit_Name(self, node: Any): ...
    def visit_Attribute(self, node: Any): ...

def ast_to_func(ast_root: Any, dyfunc: Any, delete_on_exit: bool = ...): ...
def recover_globals_attribute(src_obj: Any, dst_obj: Any) -> None: ...
def func_to_source_code(function: Any, dedent: bool = ...): ...
def ast_to_source_code(ast_node: Any): ...
def is_candidate_node(node: Any): ...
def compare_with_none(node: Any): ...

class IsControlFlowVisitor(gast.NodeVisitor):
    ast_root: Any = ...
    static_analysis_visitor: Any = ...
    node_to_wrapper_map: Any = ...
    node_var_type_map: Any = ...
    is_control_flow_num: int = ...
    def __init__(
        self, ast_node: Any, static_analysis_visitor: Optional[Any] = ..., node_var_type_map: Optional[Any] = ...
    ) -> None: ...
    def transform(self): ...
    def visit_BoolOp(self, node: Any): ...
    def visit_Compare(self, node: Any): ...
    def visit_Call(self, node: Any): ...
    def visit_Name(self, node: Any): ...
    def visit_Constant(self, node: Any): ...
    def get_compare_nodes_with_tensor(self): ...

class NameNodeReplaceTransformer(gast.NodeTransformer):
    target_name: Any = ...
    replace_node: Any = ...
    def __init__(self, root_node: Any, target_name: Any, replace_node: Any) -> None: ...
    def visit_Name(self, node: Any): ...

class ForLoopTuplePreTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_For(self, node: Any): ...
    def tuple_to_stmts(self, node: Any, tuple_name: Any, idx: Any = ...): ...
    def is_for_iter(self, for_node: Any): ...
    def is_for_enumerate_iter(self, for_node: Any): ...

class ForNodeVisitor:
    node: Any = ...
    target: Any = ...
    iter_args: Any = ...
    body: Any = ...
    iter_var_name: Any = ...
    iter_idx_name: Any = ...
    iter_var_len_name: Any = ...
    iter_zip_to_list_name: Any = ...
    iter_node: Any = ...
    enum_idx_name: Any = ...
    args_length: Any = ...
    def __init__(self, for_node: Any) -> None: ...
    def parse(self): ...
    def is_for_range_iter(self): ...
    def is_for_iter(self): ...
    def is_for_enumerate_iter(self): ...

class SplitAssignTransformer(gast.NodeTransformer):
    ast_root: Any = ...
    def __init__(self, ast_node: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Assign(self, node: Any): ...

def unwrap(func: Any): ...
def input_specs_compatible(src_input_specs: Any, desired_input_specs: Any): ...
def slice_is_num(slice_node: Any): ...



from __future__ import annotations

import unittest
from typing import Any

def conv_net(img: Any, label: Any): ...

class TestQuantizationScalePass(unittest.TestCase):
    def quantization_scale(
        self, use_cuda: Any, seed: Any, activation_quant_type: Any, weight_quant_type: str = ..., for_ci: bool = ...
    ): ...
    def test_quant_scale_cuda(self) -> None: ...
    def test_quant_scale_cpu(self) -> None: ...



from __future__ import annotations

from collections import OrderedDict
from collections.abc import Iterator
from typing import Any, Callable, Optional

from paddle import Tensor
from typing_extensions import ParamSpec, Self, TypeVar

from ..._typing import DTypeLike, PlaceLike, ShapeLike
from ...framework import ParamAttr
from ...nn.initializer import Initializer

HookParam = ParamSpec("HookParam")
Ret = TypeVar("Ret")

Hook = Callable[HookParam, Ret]  # [Generic], wait for PEP 695
PreHook = Hook[[Layer, Tensor], Tensor]  # (layer, input) -> transformed_input
PostHook = Hook[[Layer, Tensor, Tensor], Tensor]  # (layer, input, output) -> transformed_output
StateDict = dict[str, Tensor] | OrderedDict[str, Tensor]
StateDictHook = Hook[[StateDict], None]

class HookRemoveHelper:
    next_hook_id: int = ...
    def __init__(self, hooks: Any) -> None: ...
    def remove(self) -> None: ...

class Layer:
    training: bool = ...
    def __init__(self, name_scope: Optional[str] = ..., dtype: DTypeLike = ...) -> None: ...

    # Children
    def children(self) -> Iterator[Self]: ...
    def named_children(self) -> Iterator[tuple[str, Self]]: ...
    # Sublayers
    def add_sublayer(self, name: str, sublayer: Self) -> Self: ...
    def sublayers(self, include_self: bool = ...) -> Iterator[Self]: ...
    def named_sublayers(
        self,
        prefix: str = ...,
        include_self: bool = ...,
        layers_set: Optional[set[Self]] = ...,
    ) -> Iterator[tuple[str, Self]]: ...
    # Parameters
    def create_parameter(
        self,
        shape: ShapeLike,
        attr: Optional[ParamAttr] = ...,
        dtype: Optional[DTypeLike] = ...,
        is_bias: bool = ...,
        default_initializer: Optional[Initializer] = ...,
    ) -> Tensor: ...
    def parameters(self, include_sublayers: bool = ...) -> list[Tensor]: ...
    def add_parameter(self, name: str, parameter: Tensor) -> Tensor: ...
    def named_parameters(
        self,
        prefix: str = ...,
        include_sublayers: bool = ...,
    ) -> Iterator[tuple[str, Tensor]]: ...
    # Tensor
    def create_tensor(
        self,
        name: Optional[str] = ...,
        persistable: Optional[bool] = ...,
        dtype: Optional[DTypeLike] = ...,
    ) -> Tensor: ...
    # Buffer
    def register_buffer(self, name: str, tensor: Tensor, persistable: bool = ...) -> None: ...
    def buffers(self, include_sublayers: bool = ...) -> list[Tensor]: ...
    def named_buffers(
        self,
        prefix: str = ...,
        include_sublayers: bool = ...,
    ) -> Iterator[tuple[str, Tensor]]: ...

    # Training process
    def train(self) -> None: ...
    def eval(self) -> None: ...
    def forward(self, *args: Any, **kwargs: Any) -> Any: ...
    def backward(self, *inputs: Any) -> None: ...
    def clear_gradients(self) -> None: ...
    __call__ = forward

    # Hooks
    def register_forward_post_hook(self, hook: PostHook) -> HookRemoveHelper: ...
    def register_forward_pre_hook(self, hook: PreHook) -> HookRemoveHelper: ...

    # Magic methods related
    def __getattr__(self, name: str) -> Any: ...
    def __setattr__(self, name: str, value: Any) -> None: ...
    def __delattr__(self, name: str) -> None: ...
    def __dir__(self) -> list[str]: ...
    def extra_repr(self) -> str: ...

    # State dict
    def to_static_state_dict(
        self,
        destination: Optional[StateDict] = ...,
        include_sublayers: bool = ...,
        structured_name_prefix: str = ...,
        use_hook: bool = ...,
    ) -> StateDict: ...
    def state_dict(
        self,
        destination: Optional[StateDict] = ...,
        include_sublayers: bool = ...,
        structured_name_prefix: str = ...,
        use_hook: bool = ...,
    ) -> StateDict: ...
    def set_state_dict(
        self,
        state_dict: StateDict,
        use_structured_name: bool = ...,
    ) -> None: ...
    def register_state_dict_hook(self, hook: StateDictHook) -> HookRemoveHelper: ...
    # [aliases] Compatible with old method names
    set_dict = set_state_dict
    load_dict = set_state_dict

    # Others
    def to(
        self,
        device: Optional[PlaceLike] = ...,
        dtype: Optional[DTypeLike] = ...,
        blocking: Optional[bool] = ...,
    ) -> Self: ...
    def apply(self, fn: Callable[[Self], None]) -> Self: ...
    def full_name(self) -> str: ...



from __future__ import annotations

from typing import Any, Optional

from ..framework import unique_name as unique_name
from ..layer_helper import LayerHelper as LayerHelper
from .layer_function_generator import autodoc as autodoc

def get_places(device_count: Optional[Any] = ..., device_type: Optional[Any] = ...): ...



from __future__ import annotations

from .wrapper import Config as Config
from .wrapper import DataType as DataType
from .wrapper import PlaceType as PlaceType
from .wrapper import PrecisionType as PrecisionType
from .wrapper import Predictor as Predictor
from .wrapper import Tensor as Tensor



from __future__ import annotations

from typing import Any, Optional

from paddle import in_dynamic_mode as in_dynamic_mode

from ...fluid.data_feeder import check_type as check_type
from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.layer_helper import LayerHelper as LayerHelper
from .. import Layer as Layer

class PairwiseDistance(Layer):
    p: Any = ...
    epsilon: Any = ...
    keepdim: Any = ...
    name: Any = ...
    def __init__(
        self, p: float = ..., epsilon: float = ..., keepdim: bool = ..., name: Optional[Any] = ...
    ) -> None: ...
    def forward(self, x: Any, y: Any): ...
    def extra_repr(self): ...



from __future__ import annotations

from typing import Any

from paddle.distribution import distribution

class TransformedDistribution(distribution.Distribution):
    def __init__(self, base: Any, transforms: Any) -> None: ...
    def sample(self, shape: Any = ...): ...
    def log_prob(self, value: Any): ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid import core as core
from ..fluid import framework as framework
from ..fluid import layers as layers
from ..fluid import unique_name as unique_name
from ..fluid.framework import Variable as Variable
from ..fluid.layer_helper import LayerHelper as LayerHelper
from .optimizer import Optimizer as Optimizer

class Lamb(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        lamb_weight_decay: float = ...,
        beta1: float = ...,
        beta2: float = ...,
        epsilon: float = ...,
        parameters: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        exclude_from_weight_decay_fn: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

import abc
from typing import Any, Optional

class Fleet(metaclass=abc.ABCMeta):
    __metaclass__: Any = ...
    def __init__(self, mode: Any) -> None: ...
    def is_first_worker(self): ...
    def worker_index(self): ...
    def worker_num(self): ...
    def is_worker(self): ...
    def worker_endpoints(self, to_string: bool = ...): ...
    def server_num(self): ...
    def server_index(self): ...
    def server_endpoints(self, to_string: bool = ...): ...
    def is_server(self): ...
    def is_xpu(self): ...
    def split_files(self, files: Any): ...
    def init(self, role_maker: Optional[Any] = ...) -> None: ...
    def all_reduce_worker(self, input: Any, output: Any) -> None: ...
    def barrier_worker(self) -> None: ...
    @abc.abstractmethod
    def init_worker(self) -> Any: ...
    @abc.abstractmethod
    def init_server(self, model_dir: Optional[Any] = ..., **kwargs: Any) -> Any: ...
    @abc.abstractmethod
    def run_server(self) -> Any: ...
    @abc.abstractmethod
    def stop_worker(self) -> Any: ...
    @abc.abstractmethod
    def distributed_optimizer(self, optimizer: Any, strategy: Optional[Any] = ...) -> Any: ...
    @abc.abstractmethod
    def save_inference_model(
        self,
        executor: Any,
        dirname: Any,
        feeded_var_names: Any,
        target_vars: Any,
        main_program: Optional[Any] = ...,
        export_for_deployment: bool = ...,
    ) -> Any: ...
    @abc.abstractmethod
    def save_persistables(self, executor: Any, dirname: Any, main_program: Optional[Any] = ...) -> Any: ...

class DistributedOptimizer(metaclass=abc.ABCMeta):
    __metaclass__: Any = ...
    def __init__(self, optimizer: Any, strategy: Optional[Any] = ...) -> None: ...
    @abc.abstractmethod
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ) -> Any: ...
    @abc.abstractmethod
    def apply_gradients(self, params_grads: Any) -> Any: ...
    @abc.abstractmethod
    def minimize(
        self,
        losses: Any,
        scopes: Optional[Any] = ...,
        startup_programs: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ) -> Any: ...



from __future__ import annotations

from typing import Any, Optional

from . import core as core
from . import unique_name as unique_name
from .framework import OpProtoHolder as OpProtoHolder
from .framework import Parameter as Parameter
from .framework import dtype_is_floating as dtype_is_floating
from .layer_helper_base import LayerHelperBase as LayerHelperBase
from .param_attr import ParamAttr as ParamAttr

class LayerHelper(LayerHelperBase):
    kwargs: Any = ...
    def __init__(self, layer_type: Any, **kwargs: Any) -> None: ...
    def append_op(self, *args: Any, **kwargs: Any): ...
    def multiple_input(self, input_param_name: str = ...): ...
    def input(self, input_param_name: str = ...): ...
    @property
    def param_attr(self): ...
    @property
    def bias_attr(self): ...
    def multiple_param_attr(self, length: Any): ...
    def iter_inputs_and_params(self, input_param_name: str = ...) -> None: ...
    def input_dtype(self, input_param_name: str = ...): ...
    def get_parameter(self, name: Any): ...
    def append_bias_op(self, input_var: Any, dim_start: int = ..., dim_end: Optional[Any] = ...): ...
    def append_activation(self, input_var: Any): ...
    def is_instance(self, param_name: Any, cls: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ..log_helper import get_logger as get_logger

class _DatasetFetcher:
    dataset: Any = ...
    auto_collate_batch: Any = ...
    collate_fn: Any = ...
    drop_last: Any = ...
    def __init__(self, dataset: Any, auto_collate_batch: Any, collate_fn: Any, drop_last: Any) -> None: ...
    def fetch(self, batch_indices: Any, done_event: Optional[Any] = ...) -> None: ...

class _IterableDatasetFetcher(_DatasetFetcher):
    dataset_iter: Any = ...
    def __init__(self, dataset: Any, auto_collate_batch: Any, collate_fn: Any, drop_last: Any) -> None: ...
    def fetch(self, batch_indices: Any, done_event: Optional[Any] = ...): ...

class _MapDatasetFetcher(_DatasetFetcher):
    def __init__(self, dataset: Any, auto_collate_batch: Any, collate_fn: Any, drop_last: Any) -> None: ...
    def fetch(self, batch_indices: Any, done_event: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

def generate_layer_fn(op_type: Any): ...
def generate_activation_fn(op_type: Any): ...
def generate_inplace_fn(inplace_op_type: Any): ...
def autodoc(comment: str = ...): ...
def templatedoc(op_type: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

class FunctionCache:
    def __init__(self) -> None: ...
    def convert_with_cache(self, func: Any): ...
    def exist(self, func: Any): ...

def convert_to_static(function: Any): ...

class CacheKey:
    function_spec: Any = ...
    input_args_with_spec: Any = ...
    input_kwargs_with_spec: Any = ...
    class_instance: Any = ...
    kwargs: Any = ...
    def __init__(
        self,
        function_spec: Any,
        input_args_with_spec: Any,
        input_kwargs_with_spec: Any,
        class_instance: Any,
        **kwargs: Any,
    ) -> None: ...
    @classmethod
    def from_func_and_args(cls, function_spec: Any, args: Any, kwargs: Any, class_instance: Any): ...
    def __hash__(self) -> Any: ...
    def __eq__(self, other: Any) -> Any: ...
    def __neq__(self, other: Any): ...

class StaticFunction:
    def __init__(self, function: Any, input_spec: Optional[Any] = ..., **kwargs: Any) -> None: ...
    def train(self) -> None: ...
    def eval(self) -> None: ...
    def __get__(self, instance: Any, owner: Any): ...
    def __call__(self, *args: Any, **kwargs: Any): ...
    def get_concrete_program(self, *args: Any, **kwargs: Any): ...
    def get_traced_count(self): ...
    @property
    def code(self): ...
    @property
    def dygraph_function(self): ...
    @property
    def concrete_program(self): ...
    def concrete_program_specify_input_spec(self, input_spec: Optional[Any] = ..., with_hook: bool = ...): ...
    @property
    def inputs(self): ...
    @property
    def outputs(self): ...
    @property
    def main_program(self): ...
    @property
    def program_cache(self): ...
    @property
    def function_spec(self): ...

class HookHelper:
    func: Any = ...
    class_instance: Any = ...
    with_hook: Any = ...
    need_apply_hook: Any = ...
    def __init__(self, func: Any, class_instance: Any, with_hook: bool = ...) -> None: ...
    def apply_pre_hooks(self, inputs: Any): ...
    def apply_post_hooks(self, inputs: Any, outputs: Any): ...

class ConcreteProgram:
    inputs: Any = ...
    outputs: Any = ...
    main_program: Any = ...
    startup_program: Any = ...
    parameters: Any = ...
    function: Any = ...
    kwargs: Any = ...
    def __init__(
        self,
        inputs: Any,
        outputs: Any,
        parameters: Any,
        function: Any,
        main_program: Any,
        startup_program: Optional[Any] = ...,
        **kwargs: Any,
    ) -> None: ...
    @staticmethod
    def from_func_spec(func_spec: Any, input_spec: Any, input_kwargs_spec: Any, class_instance: Any, **kwargs: Any): ...

class ProgramCache:
    def __init__(self) -> None: ...
    def __getitem__(self, item: Any): ...
    def get_program(self, item: Any): ...
    def last(self): ...
    def __len__(self): ...
    def concrete_programs(self): ...

class ProgramTranslator:
    def __new__(cls, *args: Any, **kwargs: Any): ...
    @classmethod
    def get_instance(cls): ...
    @classmethod
    def reset(cls) -> None: ...
    enable_to_static: bool = ...
    def __init__(self) -> None: ...
    def enable(self, enable_to_static: Any) -> None: ...
    def get_output(self, dygraph_func: Any, *args: Any, **kwargs: Any): ...
    def get_func(self, dygraph_func: Any): ...
    def get_program(self, dygraph_func: Any, *args: Any, **kwargs: Any): ...
    def get_code(self, dygraph_func: Any): ...
    def get_program_cache(self): ...



from __future__ import annotations

from typing import Any, Optional

def accuracy(input: Any, label: Any, k: int = ..., correct: Optional[Any] = ..., total: Optional[Any] = ...): ...
def auc(
    input: Any, label: Any, curve: str = ..., num_thresholds: Any = ..., topk: int = ..., slide_steps: int = ...
): ...



from __future__ import annotations

from typing import Any, Optional

from .. import core as core
from .. import framework as framework
from ..distribute_lookup_table import (
    find_distributed_lookup_table as find_distributed_lookup_table,
)
from ..framework import Block as Block
from ..framework import Parameter as Parameter
from ..framework import Program as Program
from ..framework import default_main_program as default_main_program
from ..framework import default_startup_program as default_startup_program
from .details import VarsDistributed as VarsDistributed
from .details import delete_ops as delete_ops
from .details import wait_server_ready as wait_server_ready
from .distribute_transpiler import DistributeTranspiler as DistributeTranspiler
from .distribute_transpiler import (
    DistributeTranspilerConfig as DistributeTranspilerConfig,
)
from .distribute_transpiler import ServerRuntimeConfig as ServerRuntimeConfig
from .distribute_transpiler import same_or_split_var as same_or_split_var
from .distribute_transpiler import slice_variable as slice_variable
from .ps_dispatcher import PSDispatcher as PSDispatcher
from .ps_dispatcher import RoundRobin as RoundRobin

RPC_OP_ROLE_ATTR_NAME: Any
op_role_attr_name: Any
RPC_OP_ROLE_ATTR_VALUE: Any

class GeoSgdTranspiler(DistributeTranspiler):
    config: Any = ...
    def __init__(self, config: Optional[Any] = ...) -> None: ...
    origin_program: Any = ...
    startup_program: Any = ...
    origin_startup_program: Any = ...
    trainer_num: Any = ...
    sync_mode: bool = ...
    trainer_id: Any = ...
    pserver_endpoints: Any = ...
    vars_overview: Any = ...
    param_name_to_grad_name: Any = ...
    grad_name_to_param_name: Any = ...
    table_name: Any = ...
    has_distributed_lookup_table: Any = ...
    vars_info: Any = ...
    split_to_origin_mapping: Any = ...
    delta_vars_list: Any = ...
    sparse_var_list: Any = ...
    sparse_var_splited_list: Any = ...
    sparse_var: Any = ...
    sparse_tables: Any = ...
    trainer_startup_program: Any = ...
    def transpile(
        self,
        trainer_id: Any,
        program: Optional[Any] = ...,
        pservers: str = ...,
        trainers: int = ...,
        sync_mode: bool = ...,
        startup_program: Optional[Any] = ...,
        current_endpoint: str = ...,
    ) -> None: ...
    def get_trainer_program(self, wait_port: bool = ...): ...
    param_grad_ep_mapping: Any = ...
    def get_pserver_programs(self, endpoint: Any): ...
    pserver_program: Any = ...
    def get_pserver_program(self, endpoint: Any): ...



from __future__ import annotations

from typing import Any, Optional

class QuantizeTranspiler:
    weight_bits: Any = ...
    activation_bits: Any = ...
    weight_quantize_type: Any = ...
    activation_quantize_type: Any = ...
    window_size: Any = ...
    moving_rate: Any = ...
    helper: Any = ...
    fake_quant_op_types: Any = ...
    fake_dequant_op_types: Any = ...
    is_test: Any = ...
    global_step: Any = ...
    def __init__(
        self,
        weight_bits: int = ...,
        activation_bits: int = ...,
        activation_quantize_type: str = ...,
        weight_quantize_type: str = ...,
        window_size: int = ...,
        moving_rate: float = ...,
    ) -> None: ...
    def training_transpile(self, program: Optional[Any] = ..., startup_program: Optional[Any] = ...) -> None: ...
    def freeze_program(self, program: Any, place: Any, scope: Optional[Any] = ...): ...
    def convert_to_int8(self, program: Any, place: Any, scope: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

class TrainerFactory:
    def __init__(self) -> None: ...

class FetchHandlerMonitor:
    fetch_instance: Any = ...
    fetch_thread: Any = ...
    running_lock: Any = ...
    running: bool = ...
    def __init__(self, scope: Any, handler: Any) -> None: ...
    def handler_launch_func(self, scope: Any, handler: Any) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...



from __future__ import annotations

from typing import Any

def get_cur_scope(): ...
def enter_local_scope() -> None: ...
def leave_local_scope() -> None: ...
def var(name: Any): ...
def find_var(name: Any): ...
def scoped_function(func: Any) -> None: ...



from __future__ import annotations

import http.server as SimpleHTTPServer
from http.server import HTTPServer
from typing import Any

class KVHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
    def do_GET(self) -> None: ...
    def do_PUT(self) -> None: ...
    def do_POST(self) -> None: ...
    def do_DELETE(self) -> None: ...
    def output(self, code: Any, value: str = ...) -> None: ...
    def log_message(self, format: Any, *args: Any) -> None: ...

class KVServer(HTTPServer):
    kv_lock: Any = ...
    kv: Any = ...
    port: Any = ...
    stopped: bool = ...
    started: bool = ...
    def __init__(self, port: Any) -> None: ...
    listen_thread: Any = ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class PKVServer:
    def __init__(self, port: Any) -> None: ...
    proc: Any = ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    @property
    def started(self): ...
    @property
    def stopped(self): ...



from __future__ import annotations

from typing import Any, Optional

from .static_flops import Table as Table
from .static_flops import static_flops as static_flops

def flops(net: Any, input_size: Any, custom_ops: Optional[Any] = ..., print_detail: bool = ...): ...
def count_convNd(m: Any, x: Any, y: Any) -> None: ...
def count_leaky_relu(m: Any, x: Any, y: Any) -> None: ...
def count_bn(m: Any, x: Any, y: Any) -> None: ...
def count_linear(m: Any, x: Any, y: Any) -> None: ...
def count_avgpool(m: Any, x: Any, y: Any) -> None: ...
def count_adap_avgpool(m: Any, x: Any, y: Any) -> None: ...
def count_zero_ops(m: Any, x: Any, y: Any) -> None: ...
def count_parameters(m: Any, x: Any, y: Any) -> None: ...
def count_io_info(m: Any, x: Any, y: Any) -> None: ...

register_hooks: Any

def dynamic_flops(model: Any, inputs: Any, custom_ops: Optional[Any] = ..., print_detail: bool = ...): ...



from __future__ import annotations

from typing import Any, Optional

FLEET_GLOBAL_DICT: Any

class DistributedOptimizerImplBase:
    def __init__(self, optimizer: Any) -> None: ...
    def minimize(
        self,
        losses: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ) -> None: ...

class DistributedAdam(DistributedOptimizerImplBase):
    type: str = ...
    data_norm_name: Any = ...
    supported_embedding_types: Any = ...
    supported_embedding_grad_types: Any = ...
    op_role_key: Any = ...
    def __init__(self, optimizer: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...device import get_cudnn_version as get_cudnn_version
from ...fluid import dygraph_utils as dygraph_utils
from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.layer_helper import LayerHelper as LayerHelper
from ...fluid.layers import nn as nn
from ...fluid.layers.utils import convert_to_list as convert_to_list
from ...framework import ParamAttr as ParamAttr
from ...static import Variable as Variable
from ...tensor.manipulation import squeeze as squeeze
from ...tensor.manipulation import unsqueeze as unsqueeze
from ...tensor.math import add as add

def conv1d(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: int = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def conv2d(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: int = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def conv1d_transpose(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    output_padding: int = ...,
    groups: int = ...,
    dilation: int = ...,
    output_size: Optional[Any] = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def conv2d_transpose(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    output_padding: int = ...,
    dilation: int = ...,
    groups: int = ...,
    output_size: Optional[Any] = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def conv3d(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: int = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def conv3d_transpose(
    x: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    output_padding: int = ...,
    groups: int = ...,
    dilation: int = ...,
    output_size: Optional[Any] = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any, Optional

from ... import fluid as fluid
from ...fluid import dygraph as dygraph
from ...fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ...fluid.layer_helper import LayerHelper as LayerHelper

def l2_norm(x: Any, axis: Any, epsilon: float = ..., name: Optional[Any] = ...): ...
def norm_except_dim(p: Any, dim: Any): ...

class WeightNorm:
    name: Any = ...
    dim: Any = ...
    def __init__(self, name: Any, dim: Any) -> None: ...
    def compute_weight(self, layer: Any): ...
    @staticmethod
    def apply(layer: Any, name: Any, dim: Any): ...
    def remove(self, layer: Any) -> None: ...
    def __call__(self, layer: Any, inputs: Any) -> None: ...

def weight_norm(layer: Any, name: str = ..., dim: int = ...): ...
def remove_weight_norm(layer: Any, name: str = ...): ...



from __future__ import annotations

from typing import Any, Optional

class DistributedInfer:
    origin_main_program: Any = ...
    origin_startup_program: Any = ...
    sparse_table_maps: Any = ...
    def __init__(self, main_program: Optional[Any] = ..., startup_program: Optional[Any] = ...) -> None: ...
    def init_distributed_infer_env(
        self, exe: Any, loss: Any, role_maker: Optional[Any] = ..., dirname: Optional[Any] = ...
    ) -> None: ...
    def get_dist_infer_program(self): ...



from __future__ import annotations

from typing import Any, Optional

def load_program(model_filename: Any, is_text: bool = ...): ...
def save_program(program: Any, model_filename: str = ..., is_text: bool = ...) -> None: ...
def check_pruned_program_vars(train_prog: Any, pruned_prog: Any): ...
def graphviz(block: Any, output_dir: str = ..., filename: str = ...) -> None: ...
def program_type_trans(prog_dir: Any, prog_fn: Any, is_text: Any): ...
def check_saved_vars_try_dump(
    dump_dir: Any,
    dump_prog_fn: Any,
    is_text_dump_program: Any,
    feed_config: Any,
    fetch_config: Any,
    batch_size: int = ...,
    save_filename: Optional[Any] = ...,
): ...
def parse_program(program: Any, output_dir: Any) -> None: ...



from __future__ import annotations

from collections import defaultdict as defaultdict
from typing import Any, Optional

from paddle.fluid import core

final_state_name_mapping: Any

class Tracer(core.Tracer):
    def __init__(self) -> None: ...
    def eager_trace_op(
        self,
        type: Any,
        inputs: Any,
        outputs: Any,
        attrs: Any,
        stop_gradient: bool = ...,
        inplace_map: Optional[Any] = ...,
    ) -> None: ...
    def eager_final_state_trace_op(
        self,
        type: Any,
        inputs: Any,
        outputs: Any,
        attrs: Any,
        stop_gradient: bool = ...,
        inplace_map: Optional[Any] = ...,
    ) -> None: ...
    def trace_op(
        self,
        type: Any,
        inputs: Any,
        outputs: Any,
        attrs: Any,
        stop_gradient: bool = ...,
        inplace_map: Optional[Any] = ...,
    ) -> None: ...
    def train_mode(self) -> None: ...
    def eval_mode(self) -> None: ...



from __future__ import annotations

from typing import Any

from .helper import MPIHelper as MPIHelper

class PaddlePSInstance:
    dh: Any = ...
    def __init__(self, server_worker_mode: int = ..., proc_per_node: int = ...) -> None: ...
    def get_worker_id(self): ...
    def get_server_id(self): ...
    def is_worker(self): ...
    def is_server(self): ...
    def is_first_worker(self): ...
    def set_ip(self, ip: Any) -> None: ...
    def gather_ips(self): ...
    def get_node_cnt(self): ...
    def get_worker_num(self): ...
    def get_server_num(self): ...
    def barrier_all(self) -> None: ...
    def barrier_worker(self) -> None: ...
    def finalize(self) -> None: ...



from __future__ import annotations

from collections import OrderedDict as OrderedDict
from typing import Any

from .log_util import logger as logger

def broadcast_input_data(hcg: Any, *inputs: Any, **kwargs: Any): ...
def broadcast_mp_parameters(model: Any, hcg: Any) -> None: ...
def broadcast_dp_parameters(model: Any, hcg: Any) -> None: ...
def fused_allreduce_gradients(parameter_list: Any, hcg: Any) -> None: ...
def sharding_reduce_gradients(parameter_list: Any, hcg: Any) -> None: ...
def broadcast_sharding_parameters(model: Any, hcg: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.static import program_guard as program_guard

class VarWrapper:
    def __init__(self, var: Any, graph: Any) -> None: ...
    def name(self): ...
    def shape(self): ...

class OpWrapper:
    def __init__(self, op: Any, graph: Any) -> None: ...
    def type(self): ...
    def inputs(self, name: Any): ...
    def outputs(self, name: Any): ...

class GraphWrapper:
    program: Any = ...
    persistables: Any = ...
    teacher_persistables: Any = ...
    compiled_graph: Any = ...
    in_nodes: Any = ...
    out_nodes: Any = ...
    def __init__(self, program: Optional[Any] = ..., in_nodes: Any = ..., out_nodes: Any = ...) -> None: ...
    def ops(self): ...
    def var(self, name: Any): ...

def count_convNd(op: Any): ...
def count_leaky_relu(op: Any): ...
def count_bn(op: Any): ...
def count_linear(op: Any): ...
def count_pool2d(op: Any): ...
def count_element_op(op: Any): ...
def static_flops(program: Any, print_detail: bool = ...): ...

class Table:
    table_heads: Any = ...
    table_len: Any = ...
    data: Any = ...
    col_num: Any = ...
    def __init__(self, table_heads: Any) -> None: ...
    def add_row(self, row_str: Any) -> None: ...
    def print_row(self, row: Any) -> None: ...
    def print_shelf(self) -> None: ...
    def print_table(self) -> None: ...



from __future__ import annotations

from typing import Any

import paddle.nn as nn

from . import utils as utils

class Identity(nn.Layer):
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def forward(self, input: Any): ...

def fuse_conv_bn(model: Any) -> None: ...
def fuse_layers(model: Any, layers_to_fuse: Any, inplace: bool = ...): ...

types_to_fusion_method: Any



from __future__ import annotations

from typing import Any

from paddle.fluid import core as core
from paddle.fluid import framework as framework
from paddle.fluid.framework import Variable as Variable
from paddle.optimizer import Optimizer as Optimizer

from ...base.topology import ParallelMode as ParallelMode

class HybridParallelGradScaler:
    def __init__(self, scaler: Any, hcg: Any) -> None: ...
    def scale(self, var: Any): ...
    def minimize(self, optimizer: Any, *args: Any, **kwargs: Any): ...
    def __getattr__(self, item: Any): ...



from __future__ import annotations

from typing import Any, Optional

from .base_cost import Cost as Cost

class TensorCost:
    def __init__(
        self,
        tensor: Optional[Any] = ...,
        dist_tensor: Optional[Any] = ...,
        shape: Optional[Any] = ...,
        dtype: Optional[Any] = ...,
    ) -> None: ...
    @property
    def tensor(self): ...
    @property
    def dist_tensor(self): ...
    @property
    def shape(self): ...
    @property
    def dtype(self): ...
    @property
    def cost(self): ...
    def calc_cost(self): ...
